@@ -122,18 +122,10 @@
 #define ALLI	5
 #define PURGE   6
 #define DIAG    7
+#define NOTE    8
 
 int quiet = 0;
 
-/* prototypes */
-
-extern int MXMLCreateE(mxml_t **,char *);
-extern int MXMLAddE(mxml_t *,mxml_t *);
-extern int MXMLSetVal(mxml_t *,char *);
-extern int MXMLDestroyE(mxml_t **);
-extern int MXMLToXString(mxml_t *,char **,int *,int, char **,mbool_t);
-
-/* END prototypes */
 
 /* globals */
 
@@ -142,6 +134,48 @@ mbool_t DisplayXML = FALSE;
 /* END globals */
 
 
+/*
+ * set_note - set the note attribute for a node
+ *
+ */
+static int set_note(
+  int   con, 
+  char  *name,
+  char  *msg
+)
+{
+  char	         *errmsg;
+  struct attropl  new;
+  int             rc;
+
+  new.name     = ATTR_NODE_note;
+  new.resource = NULL;
+  new.value    = msg;
+  new.op       = SET;
+  new.next     = NULL;
+
+  rc = pbs_manager(
+    con, 
+    MGR_CMD_SET, 
+    MGR_OBJ_NODE, 
+    name, 
+    &new, 
+    NULL);
+
+  if (rc && !quiet) 
+    {
+    fprintf(stderr,"Error setting note attribute for %s - ", name);
+
+    if ((errmsg = pbs_geterrmsg(con)) != NULL)
+      fprintf(stderr,"%s\n", errmsg);
+    else
+      fprintf(stderr,"(error %d)\n", pbs_errno);
+    }
+
+  return rc;
+}
+
+
 /*
  * cmp_node_name - compare two node names, allow the second to match the
  *	first if the same up to a dot ('.') in the second; i.e.
@@ -359,6 +393,9 @@ int main(
   char	       **pa;
   struct batch_status *pbstat;
   int	flag = ALLI;
+  char	*note = NULL;
+  int	note_flag = 0;
+  int	len;
 
   /* get default server, may be changed by -s option */
 
@@ -367,7 +404,7 @@ int main(
   if (def_server == NULL)
     def_server = "";
 
-  while ((i = getopt(argc,argv,"acdlopqrs:x-:")) != EOF)
+  while ((i = getopt(argc,argv,"acdlopqrs:x-:n:")) != EOF)
     {
     switch(i) 
       {
@@ -433,6 +470,39 @@ int main(
 
         break;
 
+      case 'n':
+
+        note_flag = 1;
+
+        /* preserve any previous option other than the default,
+         * to allow -n to be combined with -o, -c, etc
+         */
+        if ( flag == ALLI )
+          flag = NOTE;
+
+        note = strdup(optarg);
+
+        if ( note != NULL )
+          {
+          /* -n n is the same as -n ""  -- it clears the note */
+          if ( !strcmp(note,"n") )
+            {
+            *note = '\0';
+            }
+
+          len = strlen(note);
+
+          if ( len > MAX_NOTE )
+            fprintf(stderr,"Warning: note exceeds length limit (%d) - server may reject it...\n",
+              MAX_NOTE);
+
+          if ( strchr(note,'\n') != NULL )
+            fprintf(stderr,"Warning: note contains a newline - server may reject it...\n");
+
+          }
+
+        break;
+
       case '-':
 
         if ((optarg != NULL) && !strcmp(optarg,"version"))
@@ -456,14 +526,11 @@ int main(
       }  /* END switch (i) */
     }    /* END while (i == getopt()) */
 
-  if ((errflg != 0) || ((flag == LIST) && (optind != argc))) 
+  if (errflg != 0) 
     {
     if (!quiet)
       {
-      fprintf(stderr,"usage:\t%s [-{c|d|o|p|r}][-s server] [-q] node node ...\n",
-        argv[0]);
-
-      fprintf(stderr,"\t%s -l [-s server] [-q]\n",
+      fprintf(stderr,"usage:\t%s [-{c|d|l|o|p|r}][-s server] [-n \"note\"] [-q] node node ...\n",
         argv[0]);
 
       fprintf(stderr,"\t%s -{a|x} [-s server] [-q] [node]\n",
@@ -492,7 +559,7 @@ int main(
 
   if ((flag == ALLI) || (flag == DOWN) || (flag == LIST) || (flag == DIAG)) 
     {
-    if ((flag == ALLI) || (flag == DIAG))
+    if ((flag == ALLI) || (flag == LIST) || (flag == DIAG))
       {
       /* allow node specification */
 
@@ -539,6 +606,16 @@ int main(
       }
     }    /* END if ((flag == ALLI) || (flag == DOWN) || (flag == LIST) || (flag == DIAG)) */
 
+
+  if ( note_flag )
+    {
+    /* set the note attrib string on specified nodes */
+    for (pa = argv + optind;*pa;pa++) 
+      {
+      set_note(con,*pa,note);
+      }
+    }
+
   switch (flag) 
     {
     case DIAG:
@@ -657,6 +734,11 @@ int main(
 
           MXMLAddE(DE,NE);
 
+          AE = NULL;
+          MXMLCreateE(&AE,"name");
+          MXMLSetVal(AE,pbstat->name,mdfString);
+          MXMLAddE(NE,AE);
+
           for (pat = pbstat->attribs;pat;pat = pat->next)
             {
             AE = NULL;
@@ -666,7 +748,7 @@ int main(
 
             MXMLCreateE(&AE,pat->name);
 
-            MXMLSetVal(AE,pat->value);
+            MXMLSetVal(AE,pat->value,mdfString);
 
             MXMLAddE(NE,AE);
             }
