@@ -94,12 +94,8 @@
 #include "cmds.h"
 #include <pbs_config.h>   /* the master config generated by configure */
 
-static char ident[] = "@(#) $RCSfile: qhold.c,v $ $Revision: 1.3 $";
 
-int main(argc, argv, envp) /* qhold */
-int argc;
-char **argv;
-char **envp;
+int main(int argc, char **argv) /* qhold */
 {
     int c;
     int errflg=0;
