@@ -132,16 +132,10 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
-#if defined(__TAIX_5)
-#undef HAVE_READLINE
-#endif /* !__TAIX_5 */
-
 #ifdef HAVE_READLINE
 /* some versions have a buggy readline header */
 #undef HAVE_CONFIG_H
-#ifndef __TDARWIN_8  /* OSX 10.4 does not support readline */
 #include <readline/tilde.h>
-#endif /* !__TDARWIN_8 && !__TAIX_5 */
 #define HAVE_CONFIG_H
 
 #include <readline/readline.h>
@@ -869,7 +863,7 @@ int check_list(
      * if all objects of the same type are wanted
      */
 
-    if (!isalpha(*backptr) && (*backptr != '@'))
+    if (!isalpha(*backptr) && (*backptr != '@') && (*backptr != ':'))
       {
       return(backptr - list ? backptr - list : 1);
       }
@@ -1040,7 +1034,7 @@ void display(
       if( format ) 
       {
 	printf("#\n# Create and define node %s\n#\n", status->name);
-	printf("# create node %s\t# unsupported operation\n", status->name);
+	printf("create node %s\n", status->name);
       } 
       else
 	printf("Node %s\n", status->name);
@@ -1105,7 +1099,15 @@ void display(
 	if ( attr->resource != NULL ) 
 	  printf(".%s", attr->resource);
 
-	if ( attr->value != NULL ) 
+	if ( (attr->value != NULL) && (attr->name != NULL) && !strcmp(attr->name,ATTR_mtime) ) 
+          {
+          time_t epoch;
+
+          epoch = (time_t)atoi(attr->value);
+          printf(" = %s",ctime(&epoch));
+          }
+           
+	else if ( attr->value != NULL ) 
 	{
 	  l = strlen(attr->name)+8;
 
