@@ -85,12 +85,8 @@
 #include "net_connect.h"
 #include <pbs_config.h>   /* the master config generated by configure */
 
-static char ident[] = "@(#) $RCSfile: qorder.c,v $ $Revision: 1.4 $";
 
-int main(argc, argv, envp)
-int argc;
-char **argv;
-char **envp;
+int main(int argc, char **argv)
 {
     char job_id1[PBS_MAXCLTJOBID+1];		/* from the command line */
     char job_id2[PBS_MAXCLTJOBID+1];		/* from the command line */
@@ -105,7 +101,6 @@ char **envp;
     int connect;
     int stat=0;
     int rc = 0;
-    extern char *PBS_get_server();
 
 
     if (argc != 3) {
