@@ -94,36 +94,38 @@
 #include "cmds.h"
 #include <pbs_config.h>   /* the master config generated by configure */
 
-static char ident[] = "@(#) $RCSfile: qrls.c,v $ $Revision: 1.3 $";
+int main(
 
-int main(argc, argv, envp) /* qrls */
-int argc;
-char **argv;
-char **envp;
-{
-    int c;
-    int errflg=0;
-    int any_failed=0;
-    int u_cnt, o_cnt, s_cnt, n_cnt;
-    char *pc;
+  int    argc,
+  char **argv)
 
-    char job_id[PBS_MAXCLTJOBID];       /* from the command line */
+  {
+  int c;
+  int errflg=0;
+  int any_failed=0;
+  int u_cnt, o_cnt, s_cnt, n_cnt;
+  char *pc;
 
-    char job_id_out[PBS_MAXCLTJOBID];
-    char server_out[MAXSERVERNAME];
-    char rmt_server[MAXSERVERNAME];
+  char job_id[PBS_MAXCLTJOBID];       /* from the command line */
+
+  char job_id_out[PBS_MAXCLTJOBID];
+  char server_out[MAXSERVERNAME];
+  char rmt_server[MAXSERVERNAME];
 
 #define MAX_HOLD_TYPE_LEN 32
-    char hold_type[MAX_HOLD_TYPE_LEN+1];
+  char hold_type[MAX_HOLD_TYPE_LEN+1];
 
 #define GETOPT_ARGS "h:"
                  
-    hold_type[0]='\0';
+  hold_type[0] = '\0';
 
-    while ((c = getopt (argc, argv, GETOPT_ARGS )) != EOF)
-        switch (c) {
-        case 'h':
-            while ( isspace((int)*optarg) ) optarg++;
+  while ((c = getopt (argc, argv, GETOPT_ARGS )) != EOF)
+    {
+    switch (c) 
+      {
+      case 'h':
+
+        while ( isspace((int)*optarg) ) optarg++;
             if ( strlen(optarg) == 0 ) {
                 fprintf(stderr, "qrls: illegal -h value\n");
                 errflg++;
@@ -154,52 +156,86 @@ char **envp;
             }
             strcpy(hold_type, optarg);
             break;
-        default :
-            errflg++;
-        }
+      default :
 
-    if (errflg || optind >= argc) {
-        static char usage[]="usage: qrls [-h hold_list] job_identifier...\n";
-        fprintf(stderr, usage);
-        exit (2);
+        errflg++;
+
+        break;
+      }
     }
 
-    for ( ; optind < argc; optind++) {
-        int connect;
-        int stat=0;
-	int located = FALSE;
+  if (errflg || optind >= argc) 
+    {
+    static char usage[]="usage: qrls [-h hold_list] job_identifier...\n";
+
+    fprintf(stderr,usage);
+
+    exit(2);
+    }
+
+  for (;optind < argc;optind++) 
+    {
+    int connect;
+    int stat=0;
+    int located = FALSE;
+
+    strcpy(job_id, argv[optind]);
+
+    if (get_server(job_id,job_id_out,server_out)) 
+      {
+      fprintf(stderr,"qrls: illegally formed job identifier: %s\n", 
+        job_id);
+
+      any_failed = 1;
+      continue;
+      }
 
-        strcpy(job_id, argv[optind]);
-        if ( get_server(job_id, job_id_out, server_out) ) {
-            fprintf(stderr, "qrls: illegally formed job identifier: %s\n", job_id);
-            any_failed = 1;
-            continue;
-        }
 cnt:
-        connect = cnt2server(server_out);
-        if ( connect <= 0 ) {
-            fprintf(stderr, "qrls: cannot connect to server %s (errno=%d)\n", 
-                    pbs_server, pbs_errno);
-            any_failed = pbs_errno;
-            continue;
+    connect = cnt2server(server_out);
+
+    if (connect <= 0) 
+      {
+      fprintf(stderr, "qrls: cannot connect to server %s (errno=%d)\n", 
+        pbs_server, 
+        pbs_errno);
+
+      any_failed = pbs_errno;
+
+      continue;
+      }
+
+    stat = pbs_rlsjob(connect,job_id_out,hold_type,NULL);
+
+    if (stat && (pbs_errno != PBSE_UNKJOBID)) 
+      {
+      prt_job_err("qrls", connect, job_id_out);
+      any_failed = pbs_errno;
+      } 
+    else if (stat && (pbs_errno == PBSE_UNKJOBID) && !located) 
+      {
+      located = TRUE;
+
+      if (locate_job(job_id_out,server_out,rmt_server)) 
+        {
+        pbs_disconnect(connect);
+
+        strcpy(server_out,rmt_server);
+
+        goto cnt;
         }
 
-        stat = pbs_rlsjob(connect, job_id_out, hold_type, NULL);
-        if ( stat && (pbs_errno != PBSE_UNKJOBID) ) {
-	    prt_job_err("qrls", connect, job_id_out);
-            any_failed = pbs_errno;
-        } else if ( stat && (pbs_errno == PBSE_UNKJOBID) && !located ) {
-	    located = TRUE;
-	    if ( locate_job(job_id_out, server_out, rmt_server) ) {
-	        pbs_disconnect(connect);
-		strcpy(server_out, rmt_server);
-		goto cnt;
-	    }
-	    prt_job_err("qrls", connect, job_id_out);
-	    any_failed = pbs_errno;
-	}
+      prt_job_err("qrls",connect,job_id_out);
+
+      any_failed = pbs_errno;
+      }
+
+    pbs_disconnect(connect);
+    }  /* END for () */
+
+  exit(any_failed);
+
+  /*NOTREACHED*/
+
+  return(0);
+  }  /* END main() */
 
-        pbs_disconnect(connect);
-    }
-    exit(any_failed);
-}
