@@ -94,7 +94,6 @@
 #include "cmds.h"
 #include <pbs_config.h>   /* the master config generated by configure */
 
-static char ident[] = "@(#) $RCSfile: qselect.c,v $ $Revision: 1.2 $";
 
 void 
 set_attrop(list, a_name, r_name, v_name, op)
@@ -255,8 +254,7 @@ char **res_pos;
 int main(
 
   int    argc,
-  char **argv,
-  char **envp)
+  char **argv)
 
   {
   int c;
