@@ -434,6 +434,8 @@ extern int      node_np_action  A_(( attribute*, void*, int));
 extern int      node_ntype A_(( attribute*, void*, int));
 extern int      node_prop_list A_(( attribute*, void*, int));
 extern int      node_status_list A_(( attribute*, void*, int));
+extern int      node_note        A_(( attribute*, void*, int));
+extern int      set_note_str     A_((attribute *attr,attribute *new, enum batch_op));
 
 /* "type" to pass to acl_check() */
 #define ACL_Host  1
