@@ -164,7 +164,7 @@ signed char disrsc A_((int stream, int *retval));
 
 /*#if CHAR_MIN, i.e. if chars are signed*/
 /* also, flip the order of statements */
-#if __CHAR_UNSIGNED__
+#ifdef __CHAR_UNSIGNED__
 #define disrc(retval, stream) (char)disruc(stream, (retval))
 #else
 #define disrc(stream, retval) (char)disrsc(stream, (retval))
@@ -221,7 +221,7 @@ int diswsi A_((int stream, int value));
 #define diswsc(stream, value) diswsi(stream, (int)(value))
 
 /*#if CHAR_MIN*/
-#if __CHAR_UNSIGNED__
+#ifdef __CHAR_UNSIGNED__
 #define diswc(stream, value) diswui(stream, (unsigned)(value))
 #else
 #define diswc(stream, value) diswsi(stream, (int)(value))
@@ -235,7 +235,7 @@ int diswl_ A_((int stream, dis_long_double_t value, unsigned int ndigs));
 #define diswd(stream, value) diswl_(stream, (dis_long_double_t)(value), DBL_DIG)
 /*#if FLT_MANT_DIG == DBL_MANT_DIG || DBL_MANT_DIG == LDBL_MANT_DIG*/
 #if SIZEOF_FLOAT == SIZEOF_DOUBLE
-#define diswf(stream, value) diswl_(stream, (dis_long_double_t)(value), FLT_DIG)
+#define diswf(stream,value) diswl_(stream,(dis_long_double_t)(value),FLT_DIG)
 #else
 int diswf A_((int stream,double value));
 #endif
@@ -268,6 +268,8 @@ struct tcp_chan {
   struct tcpdisbuf writebuf;
 
   int              IsTimeout;  /* (boolean)  1 - true */
+  int              ReadErrno;
+  int              SelectErrno;
   };
 
 #endif	/* DATA_IS_STRINGS_ */
