@@ -257,6 +257,7 @@
 #define ATTR_NODE_ntype         "ntype"
 #define ATTR_NODE_jobs          "jobs"
 #define ATTR_NODE_status        "status"
+#define ATTR_NODE_note          "note"
 
 
 
@@ -327,6 +328,8 @@
 #ifndef MAXNAMLEN
 #define MAXNAMLEN		255
 #endif
+#define MAX_NOTE		256	/* max node note length */
+#define MAX_NOTE_STR		"256"	/* max node note length as a string literal (this MUST match MAX_NOTE) */
 
 #define PBS_MAXUSER		16	/* max user name length */
 #define PBS_MAXGRPN		16	/* max group name length */
