@@ -78,7 +78,7 @@
 */
 
 /*
- * @(#) $Id: queue.h 1050 2006-10-11 23:48:34Z garrick $
+ * @(#) $Id: queue.h 1128 2006-11-07 00:36:41Z garrick $
  */
 
 /*
@@ -166,7 +166,7 @@ extern attribute_def que_attr_def[];
 /* at last we come to the queue definition itself	*/
  
 struct pbs_queue {
-	list_link	qu_link;		/* forward/backward links */
+	tlist_link	qu_link;		/* forward/backward links */
 	tlist_head	qu_jobs;		/* jobs in this queue */
 
 	struct queuefix {
