@@ -132,7 +132,7 @@
 
 int encode_inter(attr, phead, atname, rsname, mode)
 	attribute	*attr;		/* ptr to attribute */
-	list_head	*phead;		/* head of attribute list */
+	tlist_head	*phead;		/* head of attribute list */
 	char		*atname;	/* attribute name */
 	char		*rsname;	/* resource name or null */
 	int		 mode;		/* encode mode, unused here */
