@@ -108,26 +108,46 @@
 
 #include "dis.h"
 #include "dis_.h"
+#include "log.h"
 
-int diswul(stream, value)
-    int			stream;
-    unsigned long	value;
+
+
+/* encode unsigned long for transmission along stream */
+
+int diswul(
+
+  int           stream,  /* I */
+  unsigned long value)   /* I */
+
+  {
+  int		retval;
+  unsigned	ndigs;
+  char         *cp;
+
+  int           rc;
+
+  assert(stream >= 0);
+  assert(dis_puts != NULL);
+  assert(disw_commit != NULL);
+
+  cp = discul_(&dis_buffer[DIS_BUFSIZ],value,&ndigs);
+
+  *--cp = '+';
+
+  while (ndigs > 1)
+    cp = discui_(cp,ndigs,&ndigs);
+
+  retval = (*dis_puts)(stream,cp,(size_t)(&dis_buffer[DIS_BUFSIZ] - cp)) < 0 ?
+    DIS_PROTO : 
+    DIS_SUCCESS;
+ 
+  rc = (*disw_commit)(stream,retval == DIS_SUCCESS);
+
+  if (rc < 0)
     {
-	int		retval;
-	unsigned	ndigs;
-	char		*cp;
+    return(DIS_NOCOMMIT);
+    }
 
-	assert(stream >= 0);
-	assert(dis_puts != NULL);
-	assert(disw_commit != NULL);
-
-	cp = discul_(&dis_buffer[DIS_BUFSIZ], value, &ndigs);
-	*--cp = '+';
-	while (ndigs > 1)
-		cp = discui_(cp, ndigs, &ndigs);
-	retval = (*dis_puts)(stream, cp,
-			(size_t)(&dis_buffer[DIS_BUFSIZ] - cp)) < 0 ?
-			DIS_PROTO : DIS_SUCCESS;
-	return (((*disw_commit)(stream, retval == DIS_SUCCESS) < 0) ?
-	       DIS_NOCOMMIT : retval);
-}
+  return(retval);
+  }  /* END diswul() */
+ 
