@@ -106,11 +106,13 @@ int decode_DIS_RunJob(sock, preq)
 {
 	int rc;
 
+        preq->rq_ind.rq_run.rq_destin = 0;
+
 	rc = disrfst(sock, PBS_MAXSVRJOBID+1, preq->rq_ind.rq_run.rq_jid);
 	if (rc) return rc;
 
 	/* This will need to be changed for nodes for FPA */
-	rc = disrfst(sock, PBS_MAXDEST+1, preq->rq_ind.rq_run.rq_destin);
+	preq->rq_ind.rq_run.rq_destin = disrst(sock, &rc);
 	if (rc) return rc;
 	
 	preq->rq_ind.rq_run.rq_resch = disrui(sock, &rc);
