@@ -122,32 +122,45 @@ int pbs_alterjob(
       ap = ap->next;
       }
 
-		if( ap == (struct attropl *)NULL ) {
-			pbs_errno = PBSE_SYSTEM;
-			return -1;
-		}
-		ap->name = attrib->name;
-		ap->resource = attrib->resource;
-		ap->value = attrib->value;
-		ap->op = SET;
-		ap->next = (struct attropl *)NULL;
-		attrib = attrib->next;
-	}
+    if (ap == NULL) 
+      {
+      /* FAILURE */
+
+      pbs_errno = PBSE_SYSTEM;
+
+      return(-1);
+      }
+
+    ap->name = attrib->name;
+    ap->resource = attrib->resource;
+    ap->value = attrib->value;
+    ap->op = SET;
+    ap->next = (struct attropl *)NULL;
+    attrib = attrib->next;
+    }  /* END while (attrib != NULL) */
 		
-	i = PBSD_manager(c,
-		PBS_BATCH_ModifyJob,
-		MGR_CMD_SET,
-		MGR_OBJ_JOB,
-		jobid,
-		ap1,
-		extend);
+  i = PBSD_manager(
+        c,
+        PBS_BATCH_ModifyJob,
+        MGR_CMD_SET,
+        MGR_OBJ_JOB,
+        jobid,
+        ap1,
+        extend);
 		
-	/* free up the attropl we just created */
-	while( ap1 != (struct attropl *)NULL ) {
-		ap = ap1->next;
-		free( ap1 );
-		ap1 = ap;
-	}
+  /* free up the attropl we just created */
+
+  while (ap1 != NULL) 
+    {
+    ap = ap1->next;
+
+    free(ap1);
+
+    ap1 = ap;
+    }
 	
   return(i);
   }  /* END pbs_alterjob() */
+
+/* END pbsD_alterjo.c */
+
