@@ -291,6 +291,7 @@ char *msg_sched_nocall  = "Could not contact Scheduler";
 char *msg_stageinfail	= "Stage In of files failed";
 char *msg_rescunav	= "Resource temporarily unavailable";
 char *msg_maxqueued	= "Maximum number of jobs already in queue";
+char *msg_maxuserqued   = "Maximum number of jobs already in queue for user";
 char *msg_chkpointbusy	= "Checkpoint busy, may retry";
 char *msg_exceedlmt	= "Resource limit exceeds allowable";
 char *msg_badacct	= "Invalid Account";
@@ -320,6 +321,8 @@ char *msg_routeexpd     = "Time in Route Queue Expired";
 char *msg_siscomm       = "sister could not communicate";
 char *msg_sisreject     = "sister rejected";
 char *msg_toomany       = "Too many submit retries";
+char *msg_jobtype       = "Wrong job type";
+char *msg_badaclhost	= "Bad ACL entry in host list";
 
 /*
  * The following table connects error numbers with text
@@ -374,6 +377,7 @@ struct pbs_err_to_txt pbs_err_to_txt[] = {
 	{ PBSE_RESCUNAV, &msg_rescunav },
 	{ PBSE_BADGRP,  &msg_badgrp },
 	{ PBSE_MAXQUED, &msg_maxqueued },
+	{ PBSE_MAXUSERQUED, &msg_maxuserqued },
 	{ PBSE_CKPBSY, &msg_chkpointbusy },
 	{ PBSE_EXLIMIT, &msg_exceedlmt },
 	{ PBSE_BADACCT, &msg_badacct },
@@ -404,6 +408,8 @@ struct pbs_err_to_txt pbs_err_to_txt[] = {
         { PBSE_SISCOMM, &msg_siscomm },
         { PBSE_SISREJECT, &msg_sisreject },
         { PBSE_TOOMANY, &msg_toomany },
+	{ PBSE_JOBTYPE, &msg_jobtype },
+        { PBSE_BADACLHOST, &msg_badaclhost },
         { PBSE_NONE, &msg_none },
 	{ 0, (char **)0 }		/* MUST be the last entry */
 };
