@@ -83,6 +83,10 @@
 #include <netdb.h>
 #include <netinet/in.h>
 #include <memory.h>
+#if defined(NTOHL_NEEDS_ARPA_INET_H) && defined(HAVE_ARPA_INET_H)
+#include <arpa/inet.h>
+#endif
+
 #include "portability.h"
 #include "server_limits.h"
 #include "net_connect.h"
@@ -127,7 +131,7 @@ pbs_net_t get_hostaddr(
   char *hostname) /* I */
 
   {
-  static struct in_addr  hostaddr;
+  static struct in_addr hostaddr;
   struct hostent *hp;
   extern int pbs_errno;
 
@@ -146,6 +150,6 @@ pbs_net_t get_hostaddr(
   memcpy((void *)&hostaddr,(void *)hp->h_addr_list[0],hp->h_length);
 
   return((pbs_net_t)ntohl(hostaddr.s_addr));
-  }
+  }  /* END get_hostaddr() */
 
 
