@@ -84,6 +84,7 @@
 #include <stdio.h>
 #include <errno.h>
 #include <netdb.h>
+#include <string.h>
 #include "portability.h"
 #include "server_limits.h"
 #include "net_connect.h"
@@ -93,6 +94,7 @@
 #include <fcntl.h>
 #include <sys/time.h>
 
+
 /*
 ** wait for connect to complete.  We use non-blocking sockets,
 ** so have to wait for completion this way.
@@ -108,8 +110,7 @@ static int await_connect(
   int n, val, rc;
   struct timeval tv;
 
-  /* socklen_t not portable */
-  unsigned int len;
+  torque_socklen_t len;
 
   tv.tv_sec = timeout;
   tv.tv_usec = 0;
@@ -177,6 +178,7 @@ int client_to_svr(
   
   local.sin_family = AF_INET;
   local.sin_addr.s_addr = 0;
+  local.sin_port = 0;
 
   tryport = IPPORT_RESERVED - 1;
 
@@ -198,13 +200,13 @@ retry:  /* retry goto added (rentec) */
     return(PBS_NET_RC_RETRY);
     }
 
-#if !defined(__TDARWIN) || defined(__TDARWINBIND)
+#ifndef NOPRIVPORTS
 
   flags = fcntl(sock,F_GETFL);
   flags |= O_NONBLOCK;
   fcntl(sock,F_SETFL,flags);
 
-#endif /* !__TDARWIN || __TDARWINBIND */
+#endif /* !NOPRIVPORTS */
 
   /* If local privilege port requested, bind to one */
   /* must be root privileged to do this	*/
@@ -220,9 +222,32 @@ retry:  /* retry goto added (rentec) */
       (void *)&one, 
       sizeof(one));
 
-    local.sin_port = htons(tryport);
+#ifndef NOPRIVPORTS
 
-#if !defined(__TDARWIN) || defined(__TDARWINBIND)
+#ifdef HAVE_BINDRESVPORT
+    /*
+     * bindresvport seems to cause connect() failures in some odd corner case when
+     * talking to a local daemon.  So we'll only try this once and fallback to
+     * the slow loop around bind() if connect() failes with EADDRINUSE
+     * or EADDRNOTAVAIL.
+     * http://www.supercluster.org/pipermail/torqueusers/2006-June/003740.html
+     */
+
+    if (tryport == (IPPORT_RESERVED - 1))
+      {
+      if (bindresvport(sock,&local) < 0)
+        {
+        close(sock);
+
+        return(PBS_NET_RC_FATAL);
+        }
+      }
+    else
+      {
+
+#endif
+
+    local.sin_port = htons(tryport);
 
     while (bind(sock,(struct sockaddr *)&local,sizeof(local)) < 0) 
       {
@@ -249,7 +274,10 @@ retry:  /* retry goto added (rentec) */
 
       local.sin_port = htons(tryport);
       }  /* END while (bind() < 0) */
-#endif /* !__TDARWIN || __TDARWINBIND */
+#ifdef HAVE_BINDRESVPORT
+      } /* END if (tryport == (IPPORT_RESERVED - 1)) else */
+#endif /* HAVE_BINDRESVPORT */
+#endif /* !NOPRIVPORTS */
     }    /* END if (local_port != FALSE) */
 			
   /* connect to specified server host and port	*/
@@ -279,6 +307,7 @@ retry:  /* retry goto added (rentec) */
     case EADDRINUSE:
     case EADDRNOTAVAIL:
 
+#ifndef NOPRIVPORTS
       if (local_port != FALSE) 
         {
         /* continue port search (rentec) */
@@ -289,6 +318,7 @@ retry:  /* retry goto added (rentec) */
 
         goto retry;
         }
+#endif
 
       /* fall through to next case */
 
