@@ -85,6 +85,7 @@
 #include <signal.h>
 #include <string.h>
 #include <unistd.h>
+#include <stdio.h>
 #include <pwd.h>
 #include "portability.h"
 #include "libpbs.h"
@@ -97,13 +98,13 @@
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile: mom_start.c,v $ $Revision: 1.4 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 983 $";
 
 /* Global Variables */
 
 extern int	 exiting_tasks;
 extern char	 mom_host[];
-extern list_head svr_alljobs;
+extern tlist_head svr_alljobs;
 extern int	 termin_child;
 
 /* Private variables */
@@ -258,7 +259,7 @@ void scan_for_terminated()
 		}
 		DBPRT(("%s: task %d pid %d exit value %d\n", id,
 				ptask->ti_qs.ti_task, pid, exiteval))
-		kill_task(ptask, SIGKILL);
+		kill_task(ptask, SIGKILL,0);
 		ptask->ti_qs.ti_exitstat = exiteval;
 		ptask->ti_qs.ti_status = TI_STATE_EXITED;
 		pjob->ji_qs.ji_un.ji_momt.ji_exitstat = exiteval;
