@@ -95,6 +95,7 @@
 #include <string.h>
 #include <pwd.h>
 #include <unistd.h>
+#include <ctype.h>
 #include <sys/param.h>
 #include <sys/stat.h>
 #include <sys/statvfs.h>
@@ -121,6 +122,7 @@
 #include "job.h"
 #include "log.h"
 #include "mom_mach.h"
+#include "mom_func.h"
 #include "resmon.h"
 #include "../rm_dep.h"
 
@@ -356,7 +358,7 @@ static unsigned long cput_sum(pjob)
 	prstatus_t		*ps;
 	prpsinfo_t		*pi;
 
-	cputime = 0.0;
+	cputime = 0;
 	for (i=0; i<nproc; i++) {
 		pi = &proc_info[i];
 
@@ -365,7 +367,7 @@ static unsigned long cput_sum(pjob)
 		nps++;
 		if (pi->pr_state == SZOMB) {
 			cputime += tv(pi->pr_time);
-			DBPRT(("%s: ses %d pid %d (zombie) cputime %d\n",
+			DBPRT(("%s: ses %d pid %d (zombie) cputime %lu\n",
 					id, pi->pr_sid, pi->pr_pid, cputime))
 			continue;
 		}
@@ -375,12 +377,14 @@ static unsigned long cput_sum(pjob)
 			tv(ps->pr_cutime) + tv(ps->pr_cstime);
 
 		cputime += addtime;
-		DBPRT(("%s: ses %d pid %d cputime %d\n",
+		DBPRT(("%s: ses %d pid %d cputime %lu\n",
 				id, pi->pr_sid, ps->pr_pid, cputime))
 	}
 
 	if (nps == 0)
 		pjob->ji_flags |= MOM_NO_PROC;
+	else
+		pjob->ji_flags &= ~MOM_NO_PROC;
 
 	return ((unsigned long)((double)cputime * cputfactor));
 }
@@ -822,7 +826,7 @@ int mom_over_limit(pjob)
 			num = (unsigned long)((double)(time_now - pjob->ji_qs.ji_stime) * wallfactor);
 			if (num > value) {
 				sprintf(log_buffer,
-					"walltime %d exceeded limit %d",
+					"walltime %lu exceeded limit %lu",
 					num, value);
 				if (ignwalltime == 0)
 					return (TRUE);
@@ -909,9 +913,10 @@ int mom_set_use(pjob)
  *	Kill a task session.
  *	Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig)
+int kill_task(ptask, sig, pg)
     task	*ptask;
     int  	sig;
+    int         pg;
 {
 	char		*id = "kill_task";
 	int		ct = 0;
@@ -1021,7 +1026,7 @@ double
 dsecs(t)
 timestruc_t     *t;
 {
-	DBPRT(("\tsecs: %d\tnsecs: %d\n", t->tv_sec, t->tv_nsec))
+	DBPRT(("\tsecs: %lu\tnsecs: %lu\n", t->tv_sec, t->tv_nsec))
 	return ( (double)t->tv_sec + ((double)t->tv_nsec * 1.0e-9) );
 }
 
@@ -1101,7 +1106,7 @@ pid_t	pid;
 }
 
 
-static char *
+char *
 cput(attrib)
 struct	rm_attribute	*attrib;
 {
@@ -1159,11 +1164,11 @@ pid_t	jobid;
 
 		found = 1;
 		memsize += pi->pr_size;
-		DBPRT(("%s: total %d pid %d %d\n", id, memsize*page_size,
+		DBPRT(("%s: total %ld pid %d %ld\n", id, memsize*page_size,
 				pi->pr_pid, pi->pr_size*page_size))
 	}
 	if (found) {
-		sprintf(ret_string, "%ukb",(memsize*page_size) >> 10); /* KB */
+		sprintf(ret_string, "%ldkb",(memsize*page_size) >> 10); /* KB */
 		return ret_string;
 	}
 
@@ -1195,11 +1200,11 @@ pid_t	pid;
 		return NULL;
 	}
 
-	sprintf(ret_string, "%ukb", (pi->pr_size*page_size) >> 10); /* in KB */
+	sprintf(ret_string, "%ldkb", (pi->pr_size*page_size) >> 10); /* in KB */
 	return ret_string;
 }
 
-static char *
+char *
 mem(attrib)
 struct	rm_attribute	*attrib;
 {
@@ -1260,7 +1265,7 @@ pid_t	jobid;
 	}
 	if (found) {
 		/* in KB */
-		sprintf(ret_string, "%ukb", (resisize * page_size) >> 10);
+		sprintf(ret_string, "%ldkb", (resisize * page_size) >> 10);
 		return ret_string;
 	}
 
@@ -1292,7 +1297,7 @@ pid_t	pid;
 		return NULL;
 	}
 
-	sprintf(ret_string, "%ukb", (pi->pr_rssize * page_size) >> 10); /* KB */
+	sprintf(ret_string, "%ldkb", (pi->pr_rssize * page_size) >> 10); /* KB */
 	return ret_string;
 }
 
@@ -1330,7 +1335,7 @@ struct	rm_attribute	*attrib;
 	}
 }
 
-static char *
+char *
 sessions(attrib)
 struct	rm_attribute	*attrib;
 {
@@ -1395,19 +1400,22 @@ struct	rm_attribute	*attrib;
 	fmt = ret_string;
 	for (j=0; j<njids; j++) {
 		checkret(&fmt, 100);
-		sprintf(fmt, " %d", (int)jids[j]);
+                if (j==0)
+		  sprintf(fmt, "%d", (int)jids[j]);
+                else
+		  sprintf(fmt, " %d", (int)jids[j]);
 		fmt += strlen(fmt);
 	}
 	free(jids);
 	return ret_string;
 }
 
-static char *
+char *
 nsessions(attrib)
 struct	rm_attribute	*attrib;
 {
 	char	*result, *ch;
-	int	num = 0;
+	int	num = 1;
 
 	if ((result = sessions(attrib)) == NULL)
 		return result;
@@ -1420,7 +1428,7 @@ struct	rm_attribute	*attrib;
 	return ret_string;
 }
 
-static char *
+char *
 pids(attrib)
 struct	rm_attribute	*attrib;
 {
@@ -1482,7 +1490,7 @@ struct	rm_attribute	*attrib;
 	return ret_string;
 }
 
-static char *
+char *
 nusers(attrib)
 struct	rm_attribute	*attrib;
 {
@@ -1564,7 +1572,7 @@ static char *ncpus(
     return(NULL);
     }
 
-  sprintf(ret_string,"%d",
+  sprintf(ret_string,"%ld",
     sysconf(_SC_NPROCESSORS_ONLN));
 
   system_ncpus=sysconf(_SC_NPROCESSORS_ONLN);
@@ -1635,7 +1643,7 @@ static char *availmem(
 
 
 
-static char *size_fs(
+char *size_fs(
 
   char *param)
 
@@ -1715,7 +1723,7 @@ static char *size_file(
 
 
 
-static char *size(
+char *size(
 
   struct rm_attribute *attrib)
 
@@ -1765,7 +1773,7 @@ static void setmax(dev)
 
 
 
-static char *
+char *
 idletime(attrib)
 struct	rm_attribute	*attrib;
 {
@@ -1930,7 +1938,7 @@ static char *cpuspeed(
     return NULL;
   }
 
-  err = getsysinfo(GSI_GET_HWRPB, &rpbbuf, sizeof(rpbbuf));
+  err = getsysinfo(GSI_GET_HWRPB, (caddr_t)&rpbbuf, sizeof(rpbbuf));
   if (err < 0) {
     freq = 233;
   } else {
@@ -1971,7 +1979,7 @@ struct	rm_attribute	*attrib;
 	  int         err;
 	  double freq;
 
-	  err = getsysinfo(GSI_PROC_TYPE, &cputype, sizeof(cputype));
+	  err = getsysinfo(GSI_PROC_TYPE, (caddr_t)&cputype, sizeof(cputype));
 	  if (err < 0) {
 	      cputype = -1;
 	      sprintf(errbuf, "[errno = %d]", errno);
@@ -1979,7 +1987,7 @@ struct	rm_attribute	*attrib;
 	  } else {
 	    CPU_TYPE_TO_TEXT(cputype & 0xfffff, cputypename);
 	    if ( strcmp(cputypename,"") == 0 ) {
-	      sprintf(errbuf, "[error, cputype = %d]", cputype);
+	      sprintf(errbuf, "[error, cputype = %ld]", cputype);
 	    }
 	  }
 	}
