@@ -140,7 +140,7 @@
 **		loadave		current load average
 */
 
-static char ident[] = "@(#) fujitsu/$RCSfile: mom_mach.c,v $ $Revision: 1.9 $";
+static char ident[] = "@(#) fujitsu/$RCSfile$ $Revision: 991 $";
 
 #ifndef TRUE
 #define FALSE	0
@@ -407,6 +407,8 @@ static unsigned long cput_sum(pjob)
 
 	if (nps == 0)
 		pjob->ji_flags |= MOM_NO_PROC;
+	else
+		pjob->ji_flags &= ~MOM_NO_PROC;
 
 	return ((unsigned long)((double)cputime * cputfactor));
 }
@@ -917,9 +919,10 @@ int mom_set_use(pjob)
  *	Kill a task session.
  *	Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig)
+int kill_task(ptask, sig,pg)
     task	*ptask;
     int  	sig;
+    int         pg;
 {
 	char		*id = "kill_task";
 	int		ct = 0;
@@ -1402,7 +1405,10 @@ struct	rm_attribute	*attrib;
 	fmt = ret_string;
 	for (j=0; j<njids; j++) {
 		checkret(&fmt, 100);
-		sprintf(fmt, " %d", (int)jids[j]);
+                if (j==0)
+		  sprintf(fmt, "%d", (int)jids[j]);
+                else
+		  sprintf(fmt, " %d", (int)jids[j]);
 		fmt += strlen(fmt);
 	}
 	free(jids);
@@ -1414,7 +1420,7 @@ nsessions(attrib)
 struct	rm_attribute	*attrib;
 {
 	char	*result, *ch;
-	int	num = 0;
+	int	num = 1;
 
 	if ((result = sessions(attrib)) == NULL)
 		return result;
