@@ -374,6 +374,8 @@ static unsigned long cput_sum(pjob)
 
 	if (nps == 0)
 		pjob->ji_flags |= MOM_NO_PROC;
+	else
+		pjob->ji_flags &= ~MOM_NO_PROC;
 
 	return ((unsigned long)((double)cputime * cputfactor));
 }
@@ -885,9 +887,10 @@ int mom_set_use(pjob)
  *	Kill a task session.
  *	Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig)
+int kill_task(ptask, sig,pg)
     task	*ptask;
     int  	sig;
+    int         pg;
 {
 	char		        *id = "kill_task";
 	int		        ct = 0;
@@ -1351,7 +1354,10 @@ struct	rm_attribute	*attrib;
 	fmt = ret_string;
 	for (j=0; j<njids; j++) {
 		checkret(&fmt, 100);
-		sprintf(fmt, " %d", (int)jids[j]);
+                if (j==0)
+		  sprintf(fmt, "%d", (int)jids[j]);
+                else
+		  sprintf(fmt, " %d", (int)jids[j]);
 		fmt += strlen(fmt);
 	}
 	free(jids);
@@ -1363,7 +1369,7 @@ nsessions(attrib)
 struct	rm_attribute	*attrib;
 {
 	char	*result, *ch;
-	int	num = 0;
+	int	num = 1;
 
 	if ((result = sessions(attrib)) == NULL)
 		return result;
@@ -1698,8 +1704,9 @@ char *size_fs(
 
   /* in KB */
 
-  sprintf(ret_string,"%lukb", 
-    (unsigned long)(((double)fsbuf.f_bsize * (double)fsbuf.f_bfree) / 1024.0));
+  sprintf(ret_string,"%lukb:%lukb", 
+    (unsigned long)(((double)fsbuf.f_bsize * (double)fsbuf.f_bfree) / 1024.0),
+    (unsigned long)(((double)fsbuf.f_bsize * (double)fsbuf.f_blocks) / 1024.0));
 
   return(ret_string);
   }  /* END size_fs() */
