@@ -142,7 +142,7 @@
 **		quota		quota information (sizes in KB)
 */
 
-static char ident[] = "@(#) sgi/$RCSfile: mom_mach.c,v $ $Revision: 1.9 $";
+static char ident[] = "@(#) sgi/$RCSfile$ $Revision: 983 $";
 
 #define SGI_ZOMBIE_WRONG 1
 #define COMPLEX_MEM_CALC 0
@@ -413,6 +413,8 @@ static unsigned long cput_sum(pjob)
 
 	if (nps == 0)
 		pjob->ji_flags |= MOM_NO_PROC;
+	else
+		pjob->ji_flags &= ~MOM_NO_PROC;
 
 	return ((unsigned long)((double)cputime * cputfactor));
 }
@@ -896,7 +898,7 @@ int mom_get_sample()
 	aspidlist_t		*taskpids = 0;
 	ash_t			ash;
 	extern aserror_t 	aserrorcode;
-	extern list_head	svr_alljobs;
+	extern tlist_head	svr_alljobs;
 	
 
 	DBPRT(("%s: entered pagesize %d\n", id, pagesize))
@@ -1241,9 +1243,10 @@ int mom_set_use(pjob)
  *	Kill a task session.
  *	Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig)
+int kill_task(ptask, sig, pg)
     task	*ptask;
     int		sig;
+    int         pg;
 {
 	char		*id = "kill_task";
 	ash_t		ash;
