@@ -282,7 +282,7 @@ static char stat_str[] = "%d (%[^)]) %c %*d %*d %d %*d %*d %u %*u \
  * Hertz is sysconf(_SC_CLK_TCK) in get_proc_stat()
 */
 
-#define JTOS(x)  x = x / Hertz;
+#define JTOS(x)  (x) / Hertz;
 
 /*
  * Linux /proc status routine.
@@ -301,7 +301,7 @@ proc_stat_t *get_proc_stat(
   static proc_stat_t	ps;
   static char		path[1024];
   FILE                 *fd;
-  unsigned		jiffies;
+  unsigned long         jiffies;
   struct stat		sb;
 
   static int Hertz  = 0;
@@ -360,13 +360,13 @@ proc_stat_t *get_proc_stat(
 
   ps.uid = sb.st_uid;
 
-  ps.start_time = linux_time + (jiffies / 100);
+  ps.start_time = linux_time + JTOS(jiffies);
   ps.name = path;
 
-  JTOS(ps.utime)
-  JTOS(ps.stime)
-  JTOS(ps.cutime)
-  JTOS(ps.cstime)
+  ps.utime = JTOS(ps.utime);
+  ps.stime = JTOS(ps.stime);
+  ps.cutime = JTOS(ps.cutime);
+  ps.cstime = JTOS(ps.cstime);
 
   fclose(fd);
 
@@ -707,13 +707,13 @@ static unsigned long cput_sum(
   job *pjob)  /* I */
 
   {
-  char			*id = "cput_sum";
-  struct dirent		*dent;
-  ulong			cputime;
-  int			nps = 0;
-  proc_stat_t		*ps;
+  char          *id = "cput_sum";
+  struct dirent	*dent;
+  ulong          cputime;
+  int            nps = 0;
+  proc_stat_t   *ps;
 
-  cputime = 0.0;
+  cputime = 0;
 
   rewinddir(pdir);
 
@@ -744,7 +744,7 @@ static unsigned long cput_sum(
 
     if (LOGLEVEL >= 6)
       {
-      sprintf(log_buffer,"%s: session=%d pid=%d cputime=%lu (cputfactor=%lf)",
+      sprintf(log_buffer,"%s: session=%d pid=%d cputime=%lu (cputfactor=%f)",
         id, 
         ps->session, 
         ps->pid, 
@@ -757,6 +757,8 @@ static unsigned long cput_sum(
 
   if (nps == 0)
     pjob->ji_flags |= MOM_NO_PROC;
+  else
+    pjob->ji_flags &= ~MOM_NO_PROC;
 
   return((unsigned long)((double)cputime * cputfactor));
   }  /* END cput_sum() */
@@ -807,7 +809,9 @@ static int overcpu_proc(
     if (!injob(pjob,ps->session))
       continue;
 
-    cputime = (ulong)((double)(ps->cutime + ps->cstime) * cputfactor);
+    /* change from ps->cutime to ps->utime, and ps->cstime to ps->stime */
+
+    cputime = (ulong)((double)(ps->utime + ps->stime) * cputfactor);
 
     if (cputime > limit)
       {
@@ -1117,7 +1121,7 @@ int mom_set_limits(
 
     assert(pname[0] != '\0');
 
-    if (strcmp(pname,"cput") == 0) 
+    if (!strcmp(pname,"cput")) 
       {
       /* cpu time - check, if less than pcput use it */
 
@@ -1130,39 +1134,45 @@ int mom_set_limits(
         return(error(pname,retval));
         }
       } 
-    else if (strcmp(pname,"pcput") == 0) 
+    else if (!strcmp(pname,"pcput")) 
       {
-      /* process cpu time - set */
-
-      retval = gettime(pres,&value);
-
-      if (retval != PBSE_NONE)
+      if (set_mode == SET_LIMIT_SET)
         {
-        log_buffer[0] = '\0';
+        /* process cpu time - set */
 
-        return(error(pname,retval));
-        }
+        retval = gettime(pres,&value);
 
-      reslim.rlim_cur = reslim.rlim_max = 
-        (unsigned long)((double)value / cputfactor);
+        if (retval != PBSE_NONE)
+          {
+          log_buffer[0] = '\0';
 
-      if (LOGLEVEL >= 2)
-        {
-        sprintf(log_buffer,"setting cpu time limit to %ld for job %s",
-          reslim.rlim_cur,
-          pjob->ji_qs.ji_jobid);
+          return(error(pname,retval));
+          }
 
-        log_record(PBSEVENT_SYSTEM,0,id,log_buffer);
+        reslim.rlim_cur = reslim.rlim_max = 
+          (unsigned long)((double)value / cputfactor);
 
-        log_buffer[0] = '\0';
-        }
+        if (LOGLEVEL >= 2)
+          {
+          sprintf(log_buffer,"setting cpu time limit to %ld for job %s",
+            reslim.rlim_cur,
+            pjob->ji_qs.ji_jobid);
 
-      if (setrlimit(RLIMIT_CPU,&reslim) < 0)
-        {
-        log_buffer[0] = '\0';
+          log_record(PBSEVENT_SYSTEM,0,id,log_buffer);
 
-        return(error("RLIMIT_CPU",PBSE_SYSTEM));
-        }
+          log_buffer[0] = '\0';
+          }
+
+        /* NOTE: some versions of linux have a bug which causes the parent 
+                 process to receive a SIGKILL if the child's cpu limit is exceeded */
+
+        if (setrlimit(RLIMIT_CPU,&reslim) < 0)
+          {
+          log_buffer[0] = '\0';
+
+          return(error("RLIMIT_CPU",PBSE_SYSTEM));
+          }
+        }    /* END if (set_mode == SET_LIMIT_SET) */
       } 
     else if (!strcmp(pname,"file")) 
       {	
@@ -1209,7 +1219,7 @@ int mom_set_limits(
           }
         }
       } 
-    else if (strcmp(pname,"vmem") == 0) 
+    else if (!strcmp(pname,"vmem")) 
       {	
       /* check */
 
@@ -1225,7 +1235,7 @@ int mom_set_limits(
       if ((vmem_limit == 0) || (value < vmem_limit))
         vmem_limit = value;
       } 
-    else if (strcmp(pname,"pvmem") == 0) 
+    else if (!strcmp(pname,"pvmem")) 
       {	
       /* set */
 
@@ -1251,11 +1261,12 @@ int mom_set_limits(
           vmem_limit = value;
         }
       } 
-    else if (strcmp(pname,"mem") == 0) 
+    else if (!strcmp(pname,"mem") && (pjob->ji_numnodes != 1))
       {	
       /* ignore */
       } 
-    else if (strcmp(pname,"pmem") == 0) 
+    else if ((!strcmp(pname,"mem") && (pjob->ji_numnodes == 1)) ||
+              !strcmp(pname,"pmem")) 
       {	
       /* set */
 
@@ -1280,17 +1291,35 @@ int mom_set_limits(
           return(error("RLIMIT_RSS",PBSE_SYSTEM));
           }
 
+#ifdef __GATECH
+        /* NOTE:  best patch may be to change to 'vmem_limit = value;' */
+
+        if (setrlimit(RLIMIT_STACK,&reslim) < 0)
+          {
+          return(error("RLIMIT_STACK",PBSE_SYSTEM));
+          }
+
+        /* set address space */
+
+        if (setrlimit(RLIMIT_AS,&reslim) < 0)
+          {
+          return(error("RLIMIT_AS",PBSE_SYSTEM));
+          }
+#endif /* __GATECH */
+
         mem_limit = value;
 
         if (getrlimit(RLIMIT_STACK,&reslim) >= 0)
           {
+          /* NOTE:  mem_limit no longer used with UMU patch in place */
+
           mem_limit = value + reslim.rlim_cur;
           }
         }
-      } 
-    else if (strcmp(pname,"walltime") == 0) 
+      }    /* END else if (!strcmp(pname,"mem") && ... */ 
+    else if (!strcmp(pname,"walltime")) 
       {	
-      /* Check */
+      /* check */
 
       retval = gettime(pres,&value);
 
@@ -1299,7 +1328,7 @@ int mom_set_limits(
         return(error(pname,retval));
         }
       } 
-    else if (strcmp(pname,"nice") == 0) 
+    else if (!strcmp(pname,"nice")) 
       {	
       /* set nice */
 
@@ -1312,7 +1341,7 @@ int mom_set_limits(
           return(error(pname,PBSE_BADATVAL));
           }
         }
-      } 
+      }
     else if ((pres->rs_defin->rs_flags & ATR_DFLAG_RMOMIG) == 0)
       {
       /* don't recognize and not marked as ignore by mom */
@@ -1711,7 +1740,7 @@ int mom_set_use(
 
   lp = &pres->rs_value.at_val.at_size.atsv_num;
 
-  lnum = (mem_sum(pjob) + 1023) >> 10;	/* as KB */
+  lnum = (mem_sum(pjob) + 1023) >> pres->rs_value.at_val.at_size.atsv_shift;	/* as KB */
 
   *lp = MAX(*lp, lnum);
 
@@ -1725,8 +1754,12 @@ int mom_set_use(
 
   assert(pres != NULL);
 
-  pres->rs_value.at_val.at_long = 
-    (long)((double)(time_now - pjob->ji_qs.ji_stime) * wallfactor);
+  /* NOTE: starting jobs can come through here before stime is recorded */
+  if (pjob->ji_qs.ji_stime == 0)
+    pres->rs_value.at_val.at_long = 0;
+  else
+    pres->rs_value.at_val.at_long = 
+      (long)((double)(time_now - pjob->ji_qs.ji_stime) * wallfactor);
 
   /* get memory */
 
@@ -1740,12 +1773,12 @@ int mom_set_use(
 
   lp = &pres->rs_value.at_val.at_size.atsv_num;
 
-  lnum = (resi_sum(pjob) + 1023) >> 10;	/* as KB */
+  lnum = (resi_sum(pjob) + 1023) >> pres->rs_value.at_val.at_size.atsv_shift;	/* as KB */
 
   *lp = MAX(*lp,lnum);
 
   return(PBSE_NONE);
-  }
+  }  /* END mom_set_use() */
 
 
 
@@ -1753,26 +1786,46 @@ int mom_set_use(
 /*
  *	Kill a task session.
  *	Call with the task pointer and a signal number.
+ *      return number of tasks signalled (0 = failure) 
  */
 
+/* NOTE:  should support killpg() or killpidtree() (NYI) 
+          may be required for suspend resume */
+
 int kill_task(
 
-  task *ptask,
-  int   sig)
+  task *ptask,  /* I */
+  int   sig,    /* I */
+  int   pg)     /* I (1=signal process group, 0=signal master process only) */
 
   {
-  char		*id = "kill_task";
-  int		ct = 0;
+  char          *id = "kill_task";
+
+  int            ct = 0;
   struct dirent	*dent;
   proc_stat_t	*ps;
-  int		sesid;
-  pid_t         mompid;
+  int            sesid;
+  pid_t          mompid;
 
   sesid = ptask->ti_qs.ti_sid;
   mompid = getpid();
 
   if (sesid <= 1)
     {
+    if (LOGLEVEL >= 3)
+      {
+      sprintf(log_buffer,"cannot send signal %d to task (no session id)",
+        sig);
+
+      log_record(
+        PBSEVENT_ERROR,
+        PBS_EVENTCLASS_JOB,
+        ptask->ti_job->ji_qs.ji_jobid,
+        log_buffer);
+      }
+
+    /* FAILURE */
+
     return(0);
     }
 
@@ -1788,6 +1841,8 @@ int kill_task(
       log_buffer);
     }
 
+  /* pdir is global */
+
   rewinddir(pdir);
 
   while ((dent = readdir(pdir)) != NULL) 
@@ -1854,7 +1909,10 @@ int kill_task(
 
           /* give the process some time to quit gracefully first (up to 5 seconds) */
 
-          kill(ps->pid,SIGTERM);
+          if (pg == 0)
+            kill(ps->pid,SIGTERM);
+          else
+            killpg(ps->pid,SIGTERM);
 
           for (i = 0;i < 20;i++) 
             {
@@ -1889,7 +1947,10 @@ int kill_task(
 
           /* should this be replaced w/killpg() to kill all children? */
 
-          kill(ps->pid,sig);
+          if (pg == 0)
+            kill(ps->pid,sig);
+          else
+            killpg(ps->pid,sig);
           }
 
         ++ct;
@@ -1897,6 +1958,8 @@ int kill_task(
       }    /* END if (sesid == ps->session) */
     }      /* END while ((dent = readdir(pdir)) != NULL) */
 
+  /* SUCCESS */
+
   return(ct);
   }  /* END kill_task() */
 
@@ -1980,6 +2043,7 @@ int mach_checkpoint(
     /* launch the script and return success */
 
     pid = fork();
+
     if (pid > 0)
       {
       /* parent: pid = child's pid */
@@ -2028,14 +2092,16 @@ int mach_checkpoint(
  *	Return -1 on error or sid if okay.
  */
 
-long mach_restart(ptask, file)
-    task	*ptask;
-    char	*file;
-{
+long mach_restart(
+
+  task *ptask,
+  char *file)
+
+  {
   /* NOTE: Currently, we expect the application to handle this itself */
 
-	return (-1);
-}
+  return(-1);
+  }
 
 
 
@@ -2081,7 +2147,13 @@ char *cput_job(
 
     found = 1;
 
-    addtime = dsecs(ps->cutime) + dsecs(ps->cstime);
+    /* add utime and stime (AKE) */
+
+    addtime = 
+      dsecs(ps->utime) + 
+      dsecs(ps->stime) + 
+      dsecs(ps->cutime) + 
+      dsecs(ps->cstime);
 
     cputime += addtime;
 
@@ -2655,15 +2727,13 @@ char *nsessions(
 
   {
   char	*result, *ch;
-  int    num;
+  int    num = 1;
 
   if ((result = sessions(attrib)) == NULL)
     {
     return(result);
     }
 
-  num = 1;
-
   for (ch = result;*ch;ch++) 
     {
     if (*ch == ' ')		/* count blanks */
@@ -3264,11 +3334,11 @@ void scan_non_child_tasks(void)
   char *id = "scan_non_child_tasks";
 
   job *job;
-  extern list_head svr_alljobs;
+  extern tlist_head svr_alljobs;
 
   DIR *pdir;  /* use local pdir to prevent race conditions associated w/global pdir (VPAC) */
 
-  pdir=opendir("/proc");
+  pdir = opendir("/proc");
 
   for (job = GET_NEXT(svr_alljobs);job != NULL;job = GET_NEXT(job->ji_alljobs)) 
     {
@@ -3814,15 +3884,15 @@ static char *quota(
     {
     case harddata:
 
-      sprintf(ret_string,"%ukb", 
-        qi.dqb_bhardlimit >> 10);
+      sprintf(ret_string,"%lukb", 
+        (u_long)qi.dqb_bhardlimit >> 10);
 
       break;
 
     case softdata:
 
-      sprintf(ret_string,"%ukb", 
-        qi.dqb_bsoftlimit >> 10);
+      sprintf(ret_string,"%lukb", 
+        (u_long)qi.dqb_bsoftlimit >> 10);
 
       break;
 
@@ -3830,11 +3900,11 @@ static char *quota(
 
 #if defined(TENABLEQUOTA)
 #if _LINUX_QUOTA_VERSION < 2
-      sprintf(ret_string,"%ukb",
-        qi.dqb_curblocks >> 10);
+      sprintf(ret_string,"%lukb",
+        (u_long)qi.dqb_curblocks >> 10);
 #else /* _LINUX_QUOTA_VERSION < 2 */
-      sprintf(ret_string,"%ukb",
-        (unsigned int)qi.dqb_curspace >> 10);
+      sprintf(ret_string,"%lukb",
+        (u_long)qi.dqb_curspace >> 10);
 #endif /* _LINUX_QUOTA_VERSION < 2 */
 #endif /* TENABLEQUOTA */
 
@@ -3842,22 +3912,22 @@ static char *quota(
 
     case hardfile:
 
-      sprintf(ret_string,"%u", 
-        qi.dqb_ihardlimit);
+      sprintf(ret_string,"%lu", 
+        (u_long)qi.dqb_ihardlimit);
 
       break;
 
     case softfile:
 
-      sprintf(ret_string,"%u", 
-        qi.dqb_isoftlimit);
+      sprintf(ret_string,"%lu", 
+        (u_long)qi.dqb_isoftlimit);
 
       break;
 
     case currfile:
 
-      sprintf(ret_string,"%u", 
-        qi.dqb_curinodes);
+      sprintf(ret_string,"%lu", 
+        (u_long)qi.dqb_curinodes);
 
       break;
 
