@@ -90,9 +90,9 @@
 #include <sys/stat.h>
 #include <sys/wait.h>
 
-#ifndef __TOLDTTY
+#ifndef USEOLDTTY
 #include <pty.h>
-#endif /* __TOLDTTY */
+#endif /* USEOLDTTY */
 
 #include "list_link.h"
 #include "log.h"
@@ -107,7 +107,7 @@
 
 extern int	 exiting_tasks;
 extern char	 mom_host[];
-extern list_head svr_alljobs;
+extern tlist_head svr_alljobs;
 extern int	 termin_child;
 
 extern int       LOGLEVEL;
@@ -238,7 +238,7 @@ char *set_shell(
 void scan_for_terminated()
 
   {
-  static char	id[] = "scan_for_terminated";
+  static char id[] = "scan_for_terminated";
   int	 exiteval = 0;
   pid_t	 pid;
   job	*pjob;
@@ -278,12 +278,12 @@ void scan_for_terminated()
       if (pid == pjob->ji_momsubt)
         break;
 
-      /*
-      ** look for task
-      */
+      /* look for task */
 
       ptask = (task *)GET_NEXT(pjob->ji_tasks);
 
+      /* locate task with associated process id */
+
       while (ptask != NULL) 
         {
         if (ptask->ti_qs.ti_sid == pid)
@@ -316,6 +316,13 @@ void scan_for_terminated()
       continue;
       }
 
+    if (WIFEXITED(statloc))
+      exiteval = WEXITSTATUS(statloc);
+    else if (WIFSIGNALED(statloc))
+      exiteval = WTERMSIG(statloc) + 0x100;
+    else 
+      exiteval = 1;
+
     if (pid == pjob->ji_momsubt) 
       {
       if (pjob->ji_mompost) 
@@ -331,13 +338,6 @@ void scan_for_terminated()
       continue;
       }
 
-    if (WIFEXITED(statloc))
-      exiteval = WEXITSTATUS(statloc);
-    else if (WIFSIGNALED(statloc))
-      exiteval = WTERMSIG(statloc) + 0x100;
-    else 
-      exiteval = 1;
-
     if (LOGLEVEL >= 2)
       {
       sprintf(log_buffer,"for job %s, task %d, pid=%d, exitcode=%d",
@@ -353,7 +353,7 @@ void scan_for_terminated()
         log_buffer);
       }
 
-    kill_task(ptask,SIGKILL);
+    kill_task(ptask,SIGKILL,0);
 
     ptask->ti_qs.ti_exitstat = exiteval;
     ptask->ti_qs.ti_status   = TI_STATE_EXITED;
@@ -390,7 +390,7 @@ void scan_for_terminated()
 
 #define PTY_SIZE 64
 
-#ifndef __TOLDTTY
+#ifndef USEOLDTTY
 
 int open_master(
 
@@ -420,7 +420,7 @@ int open_master(
   return(master);
   }  /* END open_master() */
 
-#else /* __TOLDTTY */
+#else /* USEOLDTTY */
 
 int open_master(
 
@@ -464,7 +464,7 @@ int open_master(
   return(-1);	/* tried all entries, give up */
   }  /* END open_master() */
 
-#endif /* __TOLDTTY */
+#endif /* USEOLDTTY */
 
 
 
