@@ -95,13 +95,10 @@
 #include <sys/stat.h>
 #include <netinet/in.h>
 #include <sys/time.h>
+#if defined(NTOHL_NEEDS_ARPA_INET_H) && defined(HAVE_ARPA_INET_H)
+#include <arpa/inet.h>
+#endif
 
-#if defined(__TLINUX)
-#include <sys/vfs.h>
-#elif defined(__TDARWIN)
-#include <sys/param.h> 
-#include <sys/mount.h>
-#endif /* __TLINUX */
 
 #include "pbs_ifl.h"
 #include "pbs_error.h"
@@ -117,6 +114,7 @@
 
 
 /* Global Data Items */
+#include "Long.h"
 
 extern	unsigned int	default_server_port;
 extern	char		mom_host[];
@@ -508,6 +506,9 @@ void is_request(
 
     for (sindex = 0;sindex < PBS_MAXSERVER;sindex++)
       {
+      if (pbs_servername[sindex][0] == '\0')
+        break;
+
       if (ipaddr == MOMServerAddrs[sindex])
         {
         ServerIndex = sindex;
@@ -711,6 +712,9 @@ err:
 
   rpp_close(stream);
 
+  if (ServerIndex != -1)
+    SStream[ServerIndex] = -1;
+
   return;
   }  /* END is_request() */
 
@@ -856,12 +860,12 @@ void check_state(
     ICount = 0;
     }
 
-  /* clear node messages */
-
-  PBSNodeMsgBuf[0] = '\0';
+  /* clear node state and node messages */
 
   internal_state &= ~INUSE_DOWN;
 
+  PBSNodeMsgBuf[0] = '\0';
+
   /* conditions:  external state should be down if
      - inadequate file handles available (for period X) 
      - external health check fails
@@ -872,16 +876,18 @@ void check_state(
 #define TMINSPOOLBLOCKS 100  /* blocks available in spool directory required for proper operation */
 
 
-#if defined(__TLINUX) || defined(__TDARWIN)
+#if MOMCHECKLOCALSPOOL
   {
-  struct statfs F;
+  char *sizestr;
+  u_Long freespace;
+  extern char *size_fs(char *);  /* FIXME: put this in a header file */
 
-  if (statfs(path_spool,&F) == -1)
-    {
-    /* cannot check filesystem */
-    log_err(errno,"check_state","statfs() failed");
-    }
-  else if (F.f_bavail < TMINSPOOLBLOCKS)
+  /* size_fs() is arch-specific method in mom_mach.c */
+  sizestr=size_fs(path_spool);  /* returns "free:total" */
+
+  freespace=strTouL(sizestr,NULL,10);
+
+  if (freespace < TMINSPOOLBLOCKS)
     {
     /* inadequate disk space in spool directory */
 
@@ -892,7 +898,7 @@ void check_state(
     internal_state |= INUSE_DOWN;
     }
   }    /* END BLOCK */
-#endif /* __TLINUX || __TDARWIN */
+#endif /* MOMCHECKLOCALSPOOL */
 
   if (PBSNodeCheckPath[0] != '\0')
     {
