@@ -110,6 +110,7 @@ extern int  MOMPrologFailureCount;
 
 extern int  LOGLEVEL;
 extern int  lockfds;
+extern char *path_aux;
 
 unsigned int pe_alarm_time = PBS_PROLOG_TIME;
 static pid_t  child;
@@ -119,7 +120,7 @@ static int run_exit;
 
 extern int pe_input A_((char *));
 extern int TTmpDirName A_((job *,char *tmpdir));
-extern void encode_used A_((job *,list_head *));
+extern void encode_used A_((job *,tlist_head *));
 
 /* END extern prototypes */
 
@@ -147,7 +148,7 @@ static char *resc_to_string(
   {
   int        need;
   svrattrl  *patlist;
-  list_head  svlist;
+  tlist_head  svlist;
   attribute *pattr;
 
   int       isfirst = 1;
@@ -285,7 +286,7 @@ static void pelogalm(
  *		- argv[1] is the jobid
  *		- argv[2] is the user's name
  *		- argv[3] is the user's group name
- *		- the input file is a architecture dependent file
+ *		- the input file is an architecture-dependent file
  *		- the output and error are the job's output and error
  *	The epilogue also has:
  *		- argv[4] is the job name
@@ -342,6 +343,15 @@ int run_pelog(
     return(pelog_err(pjob,pelog,errno,"cannot stat"));
     } 
 
+  if (LOGLEVEL >= 5)
+    {
+    sprintf(log_buffer,"running %s script '%s'",
+      PPEType[which],
+      (pelog != NULL) ? pelog : "NULL");
+
+    log_record(PBSEVENT_SYSTEM,0,id,log_buffer);
+    }
+
   /* script must be owned by root, be regular file, read and execute by user *
    * and not writeable by group or other */
 
@@ -644,9 +654,9 @@ int run_pelog(
     char *envname = "PBS_SCHED_HINT";
     char *envval;
     char *envstr;
-    extern char *__get_variable(job *,char *);
+    extern char *get_job_envvar(job *,char *);
   
-    if ((envval = __get_variable(pjob,envname)) != NULL)
+    if ((envval = get_job_envvar(pjob,envname)) != NULL)
       {
       envstr = malloc((strlen(envname) + strlen(envval) + 2) * sizeof(char));
 
@@ -655,6 +665,52 @@ int run_pelog(
       }
     }
 
+    /* Set PBS_NODENUM */
+    {
+    char *envname = "PBS_NODENUM";
+    char *envstr;
+  
+    sprintf(buf,"%d",pjob->ji_nodeid);
+
+    envstr = malloc((strlen(envname) + strlen(buf) + 2) * sizeof(char));
+
+    sprintf(envstr,"%s=%d",envname,pjob->ji_nodeid);
+    putenv(envstr);
+    }
+
+    /* Set PBS_MSHOST */
+    {
+    char *envname = "PBS_MSHOST";
+    char *envstr;
+  
+    if ((pjob->ji_vnods[0].vn_host != NULL) && (pjob->ji_vnods[0].vn_host->hn_host != NULL))
+      {
+      envstr = malloc((strlen(envname) + strlen(pjob->ji_vnods[0].vn_host->hn_host) + 2) * sizeof(char));
+
+      sprintf(envstr,"%s=%s",envname,pjob->ji_vnods[0].vn_host->hn_host);
+      putenv(envstr);
+      }
+    }
+
+    /* Set PBS_NODEFILE */
+    {
+    char *envname = "PBS_NODEFILE";
+    char *envstr;
+  
+    if (pjob->ji_flags & MOM_HAS_NODEFILE)
+      {
+      sprintf(buf,"%s/%s",
+        path_aux,
+        pjob->ji_qs.ji_jobid);
+
+      envstr = malloc((strlen(envname) + strlen(buf) + 2) * sizeof(char));
+
+      sprintf(envstr,"%s=%s",envname,buf);
+      putenv(envstr);
+      }
+    }
+
+
     execv(pelog,arg);
 
     sprintf(log_buffer,"execv of %s failed: %s\n",
