@@ -142,7 +142,7 @@
 #include	"resmon.h"
 #include	"../rm_dep.h"
 
-static char ident[] = "@(#) sun/$RCSfile: mom_mach.c,v $ $Revision: 1.8 $";
+static char ident[] = "@(#) sun/$RCSfile$ $Revision: 991 $";
 
 #ifndef TRUE
 #define FALSE	0
@@ -392,6 +392,8 @@ static unsigned long cput_sum(pjob)
 
 	if (nps == 0)
 		pjob->ji_flags |= MOM_NO_PROC;
+	else
+		pjob->ji_flags &= ~MOM_NO_PROC;
 
 	return ((unsigned long)((double)cputime * cputfactor));
 }
@@ -968,9 +970,10 @@ int mom_set_use(pjob)
  *	Kill a job task.
  *	Call with the job and a signal number.
  */
-int kill_task(ptask, sig)
+int kill_task(ptask, sig, pg)
     task	*ptask;
     int		sig;
+    int         pg;
 {
 	char	*id = "kill_task";
 	int	ct = 0;
@@ -1444,7 +1447,10 @@ struct	rm_attribute	*attrib;
 	fmt = ret_string;
 	for (j=0; j<njids; j++) {
 		checkret(&fmt, 100);
-		sprintf(fmt, " %d", (int)jids[j]);
+                if (j==0)
+		  sprintf(fmt, "%d", (int)jids[j]);
+                else
+		  sprintf(fmt, " %d", (int)jids[j]);
 		fmt += strlen(fmt);
 	}
 	free(jids);
@@ -1456,7 +1462,7 @@ nsessions(attrib)
 struct	rm_attribute	*attrib;
 {
 	char	*result, *ch;
-	int	num = 0;
+	int	num = 1;
 
 	if ((result = sessions(attrib)) == NULL)
 		return result;
