@@ -135,7 +135,7 @@
 #include	"resmon.h"
 #include	"../rm_dep.h"
 
-static char ident[] = "@(#) c90/$RCSfile: mom_mach.c,v $ $Revision: 1.8 $";
+static char ident[] = "@(#) c90/$RCSfile$ $Revision: 991 $";
 
 #ifndef max
 #define max(a,b) (a>b ? a : b)
@@ -716,6 +716,8 @@ static unsigned long cput_sum(pjob)
 
 	if (nps == 0)
 		pjob->ji_flags |= MOM_NO_PROC;
+	else
+		pjob->ji_flags &= ~MOM_NO_PROC;
 
 	return ((unsigned long)((double)cputime * cputfactor));
 }
@@ -1912,9 +1914,10 @@ int mom_set_use(pjob)
  *	Kill a task session.
  *	Call with the task pointer and a signal number.
  */
-int kill_task(ptask, sig)
+int kill_task(ptask, sig, pg)
     task	*ptask;
     int		sig;
+    int         pg;
 {
 	static char	*id = "kill_task";
 	int		ct = 1;
@@ -2299,7 +2302,10 @@ struct	rm_attribute	*attrib;
 	fmt = ret_string;
 	for (j=0; j<njids; j++) {
 		checkret(&fmt, 100);
-		sprintf(fmt, " %d", (int)jids[j]);
+                if (j==0)
+		  sprintf(fmt, "%d", (int)jids[j]);
+                else
+		  sprintf(fmt, " %d", (int)jids[j]);
 		fmt += strlen(fmt);
 	}
 	free(jids);
@@ -2311,7 +2317,7 @@ nsessions(attrib)
 struct	rm_attribute	*attrib;
 {
 	char	*result, *ch;
-	int	num = 0;
+	int	num = 1;
 
 	if ((result = sessions(attrib)) == NULL)
 		return result;
