@@ -102,13 +102,13 @@
 #include "mom_mach.h"
 #include "mom_func.h"
 
-static char ident[] = "@(#) $RCSfile: mom_start.c,v $ $Revision: 1.1.1.1 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 983 $";
 
 /* Global Variables */
 
 extern int	 exiting_tasks;
 extern char	 mom_host[];
-extern list_head svr_alljobs;
+extern tlist_head svr_alljobs;
 extern int	 termin_child;
 extern time_t    time_now;
 
@@ -541,7 +541,7 @@ void scan_for_terminated()
 			exiteval = 1;
 		DBPRT(("%s: task %d sid %d exit value %d\n", id,
 				ptask->ti_qs.ti_task, sid, exiteval))
-		kill_task(ptask, SIGKILL);
+		kill_task(ptask, SIGKILL,0);
 		ptask->ti_qs.ti_exitstat = exiteval;
 		ptask->ti_qs.ti_status = TI_STATE_EXITED;
 		task_save(ptask);
