@@ -91,6 +91,10 @@
 #include <string.h>
 #include <time.h>
 #include <unistd.h>
+#if defined(NTOHL_NEEDS_ARPA_INET_H) && defined(HAVE_ARPA_INET_H)
+#include <arpa/inet.h>
+#endif
+
 
 /* local headers */
 #include "portability.h"
@@ -105,7 +109,7 @@
 
 /* Macros */
 /* File Scope Variables */
-static char ident[] = "@(#) $RCSfile: af_server.c,v $ $Revision: 1.1.1.1 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 1001 $";
 
 struct ServerSortArgs {
         Server  **array;
@@ -124,7 +128,6 @@ struct ServerSortArgs {
 static SetServer AllServers;
 
 /* External Variables */
-extern  struct  connect_handle connection[];
 /* External Functions */
 /* Structures and Unions */
 /* External Functions */
@@ -966,7 +969,8 @@ Server *server;
 {
        static  char    id[] = "ServerOpen"; 	
        struct sockaddr_in      saddr;
-       int                     new_socket, slen, sock, connect, port;
+       int                     new_socket, sock, connect, port;
+       torque_socklen_t		slen;
        char		       server_name[PBS_MAXHOSTNAME];	
        char		       *sname;
 
@@ -1751,7 +1755,7 @@ void *params;
      char	  act[15];
      char	  *bufstr;	
      char	  *tempstr = NULLSTR;
-     struct attrl attrib = {NULL, "", "", ""};
+     struct attrl attrib = {NULL, "", "", "", DFLT};
 
      if( job == NOJOB || JobStateGet(job) == DELETED )
 	return(FAIL);
