@@ -135,7 +135,7 @@ int             mask_num = 0;
 char		*configfile = NULL;	/* name of config file */
 
 char		*oldpath;
-extern char		*msg_daemonname;
+extern char	*msg_daemonname;
 char		**glob_argv;
 char		usage[] = "[-S port][-d home][-p output][-c config][-a alarm]";
 struct	sockaddr_in	saddr;
@@ -217,8 +217,8 @@ static void catch_abort(
   rlimit.rlim_cur = RLIM_INFINITY;
   rlimit.rlim_max = RLIM_INFINITY;
 
-  (void)setrlimit(RLIMIT_CORE, &rlimit);
-  (void)abort();
+  setrlimit(RLIMIT_CORE, &rlimit);
+  abort();
 
   return;
   }  /* END catch_abort() */
@@ -454,7 +454,7 @@ static int read_config(
 
 
 #if !defined(DEBUG) && !defined(NO_SECURITY_CHECK)
-  if (chk_file_sec(file,0,0,S_IWGRP|S_IWOTH, 1))
+  if (chk_file_sec(file,0,0,S_IWGRP|S_IWOTH,1))
     {
     return(-1);
     }
