@@ -101,8 +101,6 @@ int check_starvation( job_info *jinfo );
 int check_ded_time_boundry( job_info *jinfo );
 
 
-static char *ident = "$Id: check.c,v 1.4 2005/09/14 01:42:13 gstaples Exp $";
-
 /*
  *
  *	is_ok_to_run_in_queue - check to see if jobs can be run in a queue
@@ -493,7 +491,7 @@ int check_nodes( int pbs_sd, job_info *jinfo, node_info **ninfo_arr )
     if( (rc = pbs_rescquery(pbs_sd, &tmp, 1, &av, &al, &res, &down)) != 0 )
     {
       sprintf(errbuf, "pbs_resquery error: %d", rc);
-      log(PBSEVENT_SYSTEM, PBS_EVENTCLASS_NODE, jinfo -> name, errbuf );
+      sched_log(PBSEVENT_SYSTEM, PBS_EVENTCLASS_NODE, jinfo -> name, errbuf );
       return SCHD_ERROR;
     }
     else
