@@ -89,7 +89,6 @@
 #include "prime.h"
 #include "misc.h"
 
-static char *ident = "$Id: prime.c,v 1.3 2005/02/22 20:59:52 dev Exp $";
 
 /*
  *
@@ -115,7 +114,7 @@ enum prime_time is_prime_time( )
   if( conf.holiday_year != 0 ) /* year == 0: no prime-time */
   {
     if( tmptr -> tm_year > conf.holiday_year )
-      log(PBSEVENT_ADMIN, PBS_EVENTCLASS_FILE, "", "The holday file is out of date, please update it.");
+      sched_log(PBSEVENT_ADMIN, PBS_EVENTCLASS_FILE, "", "The holday file is out of date, please update it.");
     else if( tmptr -> tm_yday > last_day )
     {
       last_day = tmptr -> tm_yday;
