@@ -119,9 +119,8 @@
 #include	"sched_cmds.h"
 #include	"net_connect.h"
 
-static char ident[] = "@(#) $RCSfile: pbs_sched.c,v $ $Revision: 1.1.1.1 $";
+static char ident[] = "@(#) $RCSfile$ $Revision: 1001 $";
 
-extern	struct	connect_handle connection[];
 extern	int	pbs_errno;
 extern	int	connector;
 int		server_sock;
@@ -133,7 +132,7 @@ char		*initfil = NULL;
 char		*bodyfil = "sched_tcl";
 char		*termfil = NULL;
 char		*body = NULL;
-char		*msg_daemonname = "pbs_sched";
+extern char		*msg_daemonname;
 char		**glob_argv = NULL;
 struct	sockaddr_in	saddr;
 
@@ -541,7 +540,8 @@ server_command()
 {
 	static	char	id[] = "server_command";
 	int		new_socket;
-	int		i, slen;
+	int		i;
+	torque_socklen_t	slen;
 	int		cmd;
 	pbs_net_t	addr;
 
@@ -627,7 +627,6 @@ main(argc, argv)
 	caddr_t		curr_brk, next_brk;
 	extern	char	*optarg;
 	extern	int	optind, opterr;
-	extern	char	pbs_current_user[];
 	extern	int	rpp_fd;
 	fd_set		fdset;
 
