@@ -412,7 +412,7 @@ attribute_def job_attr_def[] = {
 	PARENT_TYPE_JOB
     },
 /* JOB_ATR_qtime */
-    {	"qtime",		/* "qtime"  (time entered queue) */
+    {	ATTR_qtime,		/* "qtime"  (time entered queue) */
 	decode_l,
 	encode_l,
 	set_l,
@@ -691,7 +691,45 @@ attribute_def job_attr_def[] = {
 	ATR_TYPE_LONG,
 	PARENT_TYPE_JOB
     },
+/* JOB_ATR_forwardx11 */
+    {	ATTR_forwardx11,	/* "forward_x11" */
+	decode_str,
+	encode_str,
+	set_str,
+	comp_str,
+	free_str,
+	NULL_FUNC,
+	ATR_DFLAG_USWR | ATR_DFLAG_MGRD | ATR_DFLAG_SELEQ | ATR_DFLAG_MOM,
+	ATR_TYPE_STR,
+	PARENT_TYPE_JOB
+    },
 	
+/* JOB_ATR_submit_args */
+    {	ATTR_submit_args,
+	decode_str,
+	encode_str,
+	set_str,
+	comp_str,
+	free_str,
+	NULL_FUNC,
+	READ_ONLY | ATR_DFLAG_SvRD | ATR_DFLAG_Creat,
+	ATR_TYPE_STR,
+	PARENT_TYPE_JOB
+    },
+
+/* JOB_ATR_umask */
+    {	ATTR_umask,
+	decode_l,
+	encode_l,
+	set_l,
+	comp_l,
+	free_null,
+	NULL_FUNC,
+	READ_WRITE | ATR_DFLAG_SELEQ | ATR_DFLAG_MOM,
+	ATR_TYPE_LONG,
+	PARENT_TYPE_JOB
+    },
+
 /* Site defined attributes if any, see site_job_attr_*.h  */
 #include "site_job_attr_def.h"
 
