@@ -128,11 +128,11 @@
 #include "acct.h"
 #include "net_connect.h"
 
+int conn_qsub(char *,long);
+
 
 /* External functions */
 
-void on_job_exit A_((struct work_task *));
-
 #ifdef PBS_MOM
 #if IBM_SP2==2		/* IBM SP PSSP 3.1 */
 void unload_sp_switch A_((job *pjob));
@@ -158,8 +158,8 @@ extern char  server_name[];
 extern time_t time_now;
 extern int   LOGLEVEL;
 
-extern list_head svr_newjobs;
-extern list_head svr_alljobs;
+extern tlist_head svr_newjobs;
+extern tlist_head svr_alljobs;
 
 
 #ifdef PBS_MOM
@@ -236,9 +236,17 @@ int remtree(
 	char		namebuf[MAXPATHLEN], *filnam;
 	int		i;
 	int		rtnv = 0;
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+	struct stat64	sb;
+#else
 	struct stat	sb;
+#endif
 
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+	if (lstat64(dirname, &sb) == -1) {
+#else
 	if (lstat(dirname, &sb) == -1) {
+#endif
 		if (errno != ENOENT)
 			log_err(errno, id, "stat");
 		return -1;
@@ -262,7 +270,11 @@ int remtree(
 
 		(void)strcpy(filnam, pdir->d_name);
 
+#if defined(HAVE_STRUCT_STAT64) && defined(HAVE_STAT64)
+		if (lstat64(namebuf, &sb) == -1) {
+#else
 		if (lstat(namebuf, &sb) == -1) {
+#endif
 			log_err(errno, id, "stat");
 			rtnv = -1;
 			continue;
@@ -298,6 +310,34 @@ int remtree(
 #else	/* PBS_MOM */
 
 
+void send_qsub_delmsg(job *pjob, char *text)
+  {
+  char *phost;
+  attribute            *pattri;
+  int qsub_sock;
+
+
+    phost = arst_string("PBS_O_HOST",&pjob->ji_wattr[(int)JOB_ATR_variables]);
+
+    if ((phost == NULL) || ((phost = strchr(phost,'=')) == NULL))
+      {
+      return;
+      }
+
+    pattri = &pjob->ji_wattr[(int)JOB_ATR_interactive];
+
+    qsub_sock = conn_qsub(phost + 1,pattri->at_val.at_long);
+
+    if (qsub_sock < 0)
+      {
+      return;
+      }
+
+    write(qsub_sock,"PBS: ",5);
+    write(qsub_sock,text,strlen(text));
+
+    close(qsub_sock);
+  }
 
 
 /*
@@ -337,6 +377,15 @@ int job_abt(
 
     account_record(PBS_ACCT_ABT,pjob,"");
     svr_mailowner(pjob,MAIL_ABORT,MAIL_NORMAL,text);
+
+    if ((pjob->ji_qs.ji_state == JOB_STATE_QUEUED) &&
+        ((pjob->ji_wattr[(int)JOB_ATR_interactive].at_flags & ATR_VFLAG_SET) &&
+         pjob->ji_wattr[(int)JOB_ATR_interactive].at_val.at_long))
+      {
+      /* interactive and not yet running... send a note to qsub */
+
+      send_qsub_delmsg(pjob,text);
+      }
     }
 
   if (old_state == JOB_STATE_RUNNING) 
@@ -407,6 +456,55 @@ int job_abt(
 #endif	/* else PBS_MOM */
 
 
+/*
+ * conn_qsub - connect to the qsub that submitted this interactive job
+ * return >= 0 on SUCCESS, < 0 on FAILURE
+ * (this was moved from resmom/mom_inter.c)
+ */
+
+
+
+int conn_qsub(
+
+  char *hostname,
+  long  port)
+
+  {
+  pbs_net_t hostaddr;
+  int s;
+
+  int flags;
+
+  if ((hostaddr = get_hostaddr(hostname)) == (pbs_net_t)0)
+    {
+    return(-1);
+    }
+
+  s = client_to_svr(hostaddr,(unsigned int)port,0);
+
+  /* NOTE:  client_to_svr() can return 0 for SUCCESS */
+
+  /* assume SUCCESS requires s > 0 (USC) was 'if (s >= 0)' */
+  /* above comment not enabled */
+
+  if (s < 0)
+    {
+    /* FAILURE */
+
+    return(-1);
+    }
+
+  /* this socket should be blocking */
+
+  flags = fcntl(s,F_GETFL);
+
+  flags &= ~O_NONBLOCK;
+
+  fcntl(s,F_SETFL,flags);
+
+  return(s);
+  }  /* END conn_qsub() */
+
 
 
 
@@ -593,6 +691,7 @@ void job_purge(
   extern char  *msg_err_purgejob;
 #ifdef PBS_MOM
   int           rc;
+  extern void MOMCheckRestart A_((void));
 #endif
 
 #ifdef PBS_MOM
@@ -796,6 +895,13 @@ void job_purge(
 
   job_free(pjob);
 
+#ifdef PBS_MOM
+  /* if no jobs are left, check if MOM should be restarted */
+
+  if (((job *)GET_NEXT(svr_alljobs)) == NULL)
+    MOMCheckRestart();
+#endif	/* PBS_MOM */
+
   return;
   }  /* END job_purge() */
 
