@@ -176,6 +176,8 @@ extern char	*path_track;
 extern char	*path_nodes;
 extern char	*path_nodes_new;
 extern char	*path_nodestate;
+extern char    *path_nodenote;
+extern char    *path_nodenote_new;
 
 extern int	 queue_rank;
 extern char	 server_name[];
@@ -424,6 +426,9 @@ int pbsd_init(
   path_nodes	 = build_path(path_priv, NODE_DESCRIP, NULL);
   path_nodes_new = build_path(path_priv, NODE_DESCRIP, new_tag);
   path_nodestate = build_path(path_priv, NODE_STATUS,  NULL);
+  path_nodenote  = build_path(path_priv, NODE_NOTE,  NULL);
+  path_nodenote_new = build_path(path_priv, NODE_NOTE, new_tag);
+
 
 #if !defined(DEBUG) && !defined(NO_SECURITY_CHECK)
 
