@@ -116,13 +116,13 @@
 
 /* global data items */
 
-list_head svr_requests;
+tlist_head svr_requests;
 
 extern struct    connection svr_conn[];
 extern struct    credential conn_credent[PBS_NET_MAX_CONNECTIONS];
 extern struct server server;
 extern char      server_host[];
-extern list_head svr_newjobs;
+extern tlist_head svr_newjobs;
 extern time_t    time_now;
 extern char  *msg_err_noqueue;
 extern char  *msg_err_malloc;
@@ -145,6 +145,10 @@ static void free_rescrq A_((struct rq_rescq *));
 
 /* END private prototypes */
 
+#ifndef PBS_MOM
+extern struct pbsnode *PGetNodeFromAddr(pbs_net_t);
+#endif
+
 /* request processing prototypes */
 void req_quejob(struct batch_request *preq);
 void req_jobcredential(struct batch_request *preq);
@@ -308,13 +312,18 @@ void process_request(
 
   if (server.sv_attr[(int)SRV_ATR_acl_host_enable].at_val.at_long) 
     {
-    /* acl enabled, check it; always allow myself */
+    /* acl enabled, check it; always allow myself and nodes */
 
-    if ((acl_check(
+    struct pbsnode *isanode;
+
+    isanode=PGetNodeFromAddr(get_connectaddr(sfds));
+
+    if ((isanode == NULL) &&
+        (strcmp(server_host,request->rq_host) != 0) &&
+        (acl_check(
          &server.sv_attr[(int)SRV_ATR_acl_hosts],
          request->rq_host, 
-         ACL_Host) == 0) &&
-       (strcmp(server_host,request->rq_host) != 0)) 
+         ACL_Host) == 0))
       {
       req_reject(PBSE_BADHOST,0,request,NULL,NULL);
 
@@ -679,7 +688,7 @@ void dispatch_request(
 
       break;
 
-#ifndef PBS_MOM		/* Server Only Functions */
+#ifndef PBS_MOM		/* server only functions */
 
     case PBS_BATCH_StatusQue: 
 
@@ -1012,6 +1021,14 @@ void free_br(
 
       break;
 
+    case PBS_BATCH_RunJob:
+    case PBS_BATCH_AsyrunJob:
+
+      if (preq->rq_ind.rq_run.rq_destin)
+        free(preq->rq_ind.rq_run.rq_destin);
+
+      break;
+
 #endif /* !PBS_MOM */
 
     default:
