@@ -129,8 +129,8 @@ static void post_job_delete_nanny A_((struct work_task *));
 
 /* Public Functions in this file */
 
-struct work_task *apply_job_delete_nanny A_((struct job *, int));
-int has_job_delete_nanny A_((struct job *pjob));
+struct work_task *apply_job_delete_nanny A_((struct job *,int));
+int has_job_delete_nanny A_((struct job *));
  
 /* Private Data Items */
 
@@ -139,7 +139,7 @@ static char *delpurgestr = DELPURGE;
 
 /* Extern Functions */
 
-extern void set_resc_assigned(job *, enum batch_op op);
+extern void set_resc_assigned(job *,enum batch_op);
 
 
 /* 
@@ -448,7 +448,12 @@ jump:
 
     /* force new connection */
 
-    set_task(WORK_Immed,0,on_job_exit,(void *)pjob);
+    pwtnew = set_task(WORK_Immed,0,on_job_exit,(void *)pjob);
+
+    if (pwtnew)
+      {
+      append_link(&pjob->ji_svrtask,&pwtnew->wt_linkobj,pwtnew);
+      }
     } 
   else if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_StagedIn) != 0) 
     {
@@ -587,10 +592,9 @@ static void post_delete_mom1(
     {
     pque = pjob->ji_qhdr;
 
-    if (pque->qu_attr[(int)QE_ATR_KillDelay].at_flags & ATR_VFLAG_SET)
-      delay = pque->qu_attr[(int)QE_ATR_KillDelay].at_val.at_long;
-    else
-      delay = 2;
+    delay = attr_ifelse_long(&pque->qu_attr[(int)QE_ATR_KillDelay],
+                             &server.sv_attr[(int)SRV_ATR_KillDelay],
+                             2);
     }
 
   pwtnew = set_task(WORK_Timed,delay + time_now,post_delete_mom2,pjob);
@@ -674,10 +678,10 @@ static int forced_jobpurge(
 
   if (preq->rq_extend != NULL) 
     {
-    if (strncmp(preq->rq_extend,delpurgestr,strlen(delpurgestr)) == 0) 
+    if (!strncmp(preq->rq_extend,delpurgestr,strlen(delpurgestr))) 
       {
-      if ((preq->rq_perm & (ATR_DFLAG_OPRD|ATR_DFLAG_OPWR|
-                            ATR_DFLAG_MGRD|ATR_DFLAG_MGWR)) != 0)
+      if (((preq->rq_perm & (ATR_DFLAG_OPRD|ATR_DFLAG_OPWR|ATR_DFLAG_MGRD|ATR_DFLAG_MGWR)) != 0) || 
+          ((svr_chk_owner(preq,pjob) == 0) && (server.sv_attr[(int)SRV_ATR_OwnerPurge].at_val.at_long)))
         {
         sprintf(log_buffer,"purging job without checking MOM");
 
@@ -699,6 +703,8 @@ static int forced_jobpurge(
         } 
       else
         {
+        /* FAILURE */
+
         req_reject(PBSE_PERM,0,preq,NULL,NULL);
 
         return(-1);
