@@ -1416,13 +1416,16 @@ void on_job_rerun(
 
       /* Now re-queue the job */
 
-      if ((pjob->ji_qs.ji_svrflags | JOB_SVFLG_HOTSTART) == 0) 
+      if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HOTSTART) == 0) 
         {
         /* in case of server shutdown, don't clear exec_host */
-        /* will use it on hotstart when next comes up	     */
+        /* and session_id.  Will use it on hotstart when next comes up */
 
         job_attr_def[(int)JOB_ATR_exec_host].at_free(
           &pjob->ji_wattr[(int)JOB_ATR_exec_host]);
+
+        job_attr_def[(int)JOB_ATR_session_id].at_free(
+          &pjob->ji_wattr[(int)JOB_ATR_session_id]);
         }
 
       pjob->ji_modified = 1;	/* force full job save */
