@@ -108,24 +108,24 @@
 #include "net_connect.h"
 #include "pbs_proto.h"
 
-#ifdef __TDARWIN
+#ifdef HAVE_NETINET_IN_H
 #include <netinet/in.h>
-#endif  /* END __TDARWIN */
+#endif  /* HAVE_NETINET_IN_H */
 
 /* External Functions Called: */
 
-extern int   send_job A_((job *,pbs_net_t,int,int,void (*x)(),struct batch_request *));
-extern void  set_resc_assigned A_((job *, enum batch_op));
+extern int                   send_job A_((job *,pbs_net_t,int,int,void (*x)(),struct batch_request *));
+extern void                  set_resc_assigned A_((job *, enum batch_op));
 extern struct batch_request *cpy_stage A_((struct batch_request *,job *,enum job_atr,int));
-void      stream_eof A_((int,u_long,int));
-extern int job_set_wait(attribute *,void *,int);
-extern void stat_mom_job A_((job *));
+void                         stream_eof A_((int,u_long,int));
+extern int                   job_set_wait(attribute *,void *,int);
+extern void                  stat_mom_job A_((job *));
 
 extern int LOGLEVEL;  
 
 /* Public Functions in this file */
 
-int  svr_startjob A_((job *,struct batch_request *));
+int  svr_startjob A_((job *,struct batch_request *,char *,char *));
 
 /* Private Functions local to this file */
 
@@ -133,7 +133,7 @@ static void post_sendmom A_((struct work_task *));
 static int  svr_stagein A_((job *,struct batch_request *,int,int)); 
 static int  svr_strtjob2 A_((job *,struct batch_request *));
 static job *chk_job_torun A_((struct batch_request *,int));
-static int  assign_hosts A_((job *,char *,int));
+static int  assign_hosts A_((job *,char *,int,char *,char *));
 
 /* Global Data Items: */
 
@@ -179,6 +179,9 @@ void req_runjob(
 
   int   setneednodes;
 
+  char  failhost[1024];
+  char  emsg[1024];
+
   /* chk_job_torun will extract job id and assign hostlist if specified */
 
   if (getenv("TORQUEAUTONN"))
@@ -188,7 +191,7 @@ void req_runjob(
 
   if ((pjob = chk_job_torun(preq,setneednodes)) == NULL)
     {
-    /* FAILURE */
+    /* FAILURE - chk_job_torun performs req_reject internally */
 
     return;
     }
@@ -222,7 +225,7 @@ void req_runjob(
 
   /* NOTE:  nodes assigned to job in svr_startjob() */
 
-  rc = svr_startjob(pjob,preq);
+  rc = svr_startjob(pjob,preq,failhost,emsg);
 
   if ((rc != 0) && (preq != NULL)) 
     {
@@ -236,7 +239,7 @@ void req_runjob(
       }
     else
       {
-      req_reject(rc,0,preq,NULL,NULL);
+      req_reject(rc,0,preq,failhost,emsg);
       }
     }
 
@@ -369,7 +372,7 @@ static void post_stagein(
         svr_setjobstate(pjob,newstate,newsub);
         }
       }
-    }
+    }    /* END if (pjob != NULL) */
 
   release_req(pwt);	/* close connection and release request */
 
@@ -453,8 +456,10 @@ static int svr_stagein(
 
 int svr_startjob(
 
-  job                  *pjob,	/* job to run */
-  struct batch_request *preq)	/* Run Job batch request (optional) */
+  job                  *pjob,     /* I job to run (modified) */
+  struct batch_request *preq,     /* I Run Job batch request (optional) */
+  char                 *FailHost, /* O (optional,minsize=1024) */
+  char                 *EMsg)     /* O (optional,minsize=1024) */
 
   {
   int     f;
@@ -470,6 +475,12 @@ int svr_startjob(
   char     *id = "svr_startjob";
 #endif
 
+  if (FailHost != NULL)
+    FailHost[0] = '\0';
+
+  if (EMsg != NULL)
+    EMsg[0] = '\0';
+
   /* if not already setup, transfer the control/script file basename */
   /* into an attribute accessible by MOM */
 
@@ -499,20 +510,29 @@ int svr_startjob(
       (pjob->ji_qs.ji_svrflags & JOB_SVFLG_CHKPT)) && 
      ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_HasNodes) == 0)) 
     {
-    rc = assign_hosts(    /* inside req_runjob() */
+    rc = assign_hosts(    /* inside svr_startjob() */
            pjob,
            pjob->ji_wattr[(int)JOB_ATR_exec_host].at_val.at_str,
-           0);
+           0,
+           FailHost,
+           EMsg);
     } 
   else if (f == 0) 
     {
     /* exec_host not already set, get hosts and set it */
 
-    rc = assign_hosts(pjob,NULL,1);  /* inside req_runjob() */
+    rc = assign_hosts(
+      pjob,
+      NULL,
+      1,
+      FailHost,
+      EMsg);  /* inside svr_startjob() */
     }
 
   if (rc != 0)
     {
+    /* FAILURE */
+
     return(rc);
     }
 
@@ -540,7 +560,7 @@ int svr_startjob(
 
   while (nodestr != NULL)
     {
-    /* Truncate from trailing slash on (if one exists). */
+    /* truncate from trailing slash on (if one exists). */
 
     if ((cp = strchr(nodestr,'/')) != NULL)
       {
@@ -551,10 +571,21 @@ int svr_startjob(
 
     if ((hp = gethostbyname(nodestr)) == NULL)
       {
-      sprintf(log_buffer,"could not contact %s (gethostbyname failed)",
-        nodestr);
+      sprintf(log_buffer,"could not contact %s (gethostbyname failed, errno: %d)",
+        nodestr,
+        errno);
 
-      log_err(errno,id,log_buffer);
+      if (FailHost != NULL)
+        strncpy(FailHost,nodestr,1024);
+
+      if (EMsg != NULL)
+        strncpy(EMsg,log_buffer,1024);
+
+      log_record(
+        PBSEVENT_JOB,
+        PBS_EVENTCLASS_JOB,
+        pjob->ji_qs.ji_jobid,
+        log_buffer);
 
       /* Add this host to the reject destination list for the job */
 
@@ -573,19 +604,32 @@ int svr_startjob(
 
       append_link(&pjob->ji_rejectdest,&bp->bp_link,bp);
 
+      /* FAILURE - cannot lookup master compute host */
+
       return(PBSE_RESCUNAV);
       }
 
-    /* Open a socket. */
+    /* open a socket. */
 
     /* NOTE:  should change to PF_* */
 
     if ((sock = socket(AF_INET,SOCK_STREAM,0)) == -1)
       {
-      sprintf(log_buffer,"could not contact %s (socket failed)",
-        nodestr);
+      sprintf(log_buffer,"could not contact %s (cannot create socket, errno: %d)",
+        nodestr,
+        errno);
 
-      log_err(errno,id,log_buffer);
+      if (FailHost != NULL)
+        strncpy(FailHost,nodestr,1024);
+
+      if (EMsg != NULL)
+        strncpy(EMsg,log_buffer,1024);
+
+      log_record(
+        PBSEVENT_JOB,
+        PBS_EVENTCLASS_JOB,
+        pjob->ji_qs.ji_jobid,
+        log_buffer);
 
       /* Add this host to the reject destination list for the job */
 
@@ -597,7 +641,7 @@ int svr_startjob(
 
         log_err(errno,id,msg_err_malloc);
 
-        return;
+        return(PBSE_RESCUNAV);
         }
 
       CLEAR_LINK(bp->bp_link);
@@ -606,6 +650,8 @@ int svr_startjob(
 
       append_link(&pjob->ji_rejectdest,&bp->bp_link,bp);
 
+      /* FAILURE - cannot create socket for master compute host */
+
       return(PBSE_RESCUNAV);
       }
 
@@ -620,8 +666,21 @@ int svr_startjob(
 
     if (connect(sock,(struct sockaddr *)&saddr,sizeof(saddr)) < 0)
       {
-      sprintf(log_buffer,"could not contact %s (connect failed)",nodestr);
-      log_err(errno,id,log_buffer);
+      sprintf(log_buffer,"could not contact %s (connect failed, errno: %d)",
+        nodestr,
+        errno);
+
+      if (FailHost != NULL)
+        strncpy(FailHost,nodestr,1024);
+
+      if (EMsg != NULL)
+        strncpy(EMsg,log_buffer,1024);
+
+      log_record(
+        PBSEVENT_JOB,
+        PBS_EVENTCLASS_JOB,
+        pjob->ji_qs.ji_jobid,
+        log_buffer);
 
       /* Add this host to the reject list for the job */
 
@@ -633,7 +692,7 @@ int svr_startjob(
 
         log_err(errno,id,msg_err_malloc);
 
-        return;
+        return(PBSE_RESCUNAV);
         }
 
       CLEAR_LINK(bp->bp_link);
@@ -642,12 +701,15 @@ int svr_startjob(
 
       append_link(&pjob->ji_rejectdest,&bp->bp_link,bp);
 
+      /* FAILURE - cannot connect to master compute host */
+
       return(PBSE_RESCUNAV);
       }
 
-    /* Clean up and get next host. */
+    /* clean up and get next host. */
 
     close(sock);
+
     nodestr = strtok(NULL,"+");
     }  /* END while (nodestr != NULL) */
 
@@ -680,7 +742,7 @@ int svr_startjob(
     rc = svr_strtjob2(pjob,preq);
     }
 
-  return (rc);
+  return(rc);
   }  /* END svr_startjob() */
 
 
@@ -774,6 +836,7 @@ static void post_sendmom(
 
   {
   char	*id = "post_sendmom";
+
   int	 newstate;
   int	 newsub;
   int	 r;
@@ -781,6 +844,11 @@ static void post_sendmom(
   job	*jobp = (job *)pwt->wt_parm1;
   struct batch_request *preq = (struct batch_request *)pwt->wt_parm2;
 
+  char  *MOMName = NULL;
+
+  int    jindex;
+  long DTime = time_now - 10000;
+
   if (LOGLEVEL >= 6)
     {
     log_record(
@@ -816,28 +884,26 @@ static void post_sendmom(
 
   /* maintain local struct to associate job id with dispatch time */
 
+  for (jindex = 0;jindex < 20;jindex++)
+    {
+    if (DispatchJob[jindex] == jobp)
+      {
+      DTime = DispatchTime[jindex];
+
+      DispatchJob[jindex] = NULL;
+
+      MOMName = DispatchNode[jindex];
+
+      break;
+      }
+    }
+
   if (LOGLEVEL >= 1)
     {
-    int jindex;
-
-    long DTime = time_now - 10000;
-
-    for (jindex = 0;jindex < 20;jindex++)
-      {
-      if (DispatchJob[jindex] == jobp)
-        {
-        DTime = DispatchTime[jindex];
-
-        DispatchJob[jindex] = NULL;
-
-        break;
-        }
-      }
-
     sprintf(log_buffer,"child reported %s for job after %ld seconds (dest=%s), rc=%d",
       (r == 0) ? "success" : "failure",
       time_now - DTime,
-      (DispatchNode[jindex] != NULL) ? DispatchNode[jindex] : "???",
+      (MOMName != NULL) ? MOMName : "???",
       r);
 
     log_event(
@@ -919,7 +985,7 @@ static void post_sendmom(
       if (jobp->ji_qs.ji_substate != JOB_SUBSTATE_ABORT)
         {
         if (preq != NULL)
-          req_reject(PBSE_MOMREJECT,0,preq,NULL,"connection to mom timed out");
+          req_reject(PBSE_MOMREJECT,0,preq,MOMName,"connection to mom timed out");
 
         svr_evaljobstate(jobp,&newstate,&newsub,1);
 
@@ -928,7 +994,7 @@ static void post_sendmom(
       else
         {
         if (preq != NULL)
-          req_reject(PBSE_BADSTATE,0,preq,NULL,"job was aborted by mom");
+          req_reject(PBSE_BADSTATE,0,preq,MOMName,"job was aborted by mom");
         }
 
       break;
@@ -967,10 +1033,11 @@ static void post_sendmom(
             }
           else
             { 
-            sprintf(tmpLine,"send failed, %s",
+            sprintf(tmpLine,"cannot send job to %s, state=%s",
+              (MOMName != NULL) ? MOMName : "mom",
               PJobSubState[jobp->ji_qs.ji_substate]);
           
-            req_reject(PBSE_MOMREJECT,0,preq,NULL,tmpLine);
+            req_reject(PBSE_MOMREJECT,0,preq,MOMName,tmpLine);
             }
           }
 
@@ -994,7 +1061,7 @@ static void post_sendmom(
       else 
         {
         if (preq != NULL)
-          req_reject(PBSE_BADSTATE,0,preq,NULL,"send failed - abort");
+          req_reject(PBSE_BADSTATE,0,preq,MOMName,"send failed - abort");
         }
 			
       break;
@@ -1020,10 +1087,15 @@ static job *chk_job_torun(
   int                   setnn) /* I */
 
   {
+  static char *id = "chk_job_torun";
+
   job              *pjob;
   struct rq_runjob *prun;
   int               rc;
 
+  char              EMsg[1024];
+  char              FailHost[1024];
+
   prun = &preq->rq_ind.rq_run;
 
   if ((pjob = chk_job_request(prun->rq_jid,preq)) == 0)
@@ -1041,7 +1113,7 @@ static job *chk_job_torun(
     {
     /* FAILURE - job already started */
 
-    req_reject(PBSE_BADSTATE,0,preq,NULL,NULL);
+    req_reject(PBSE_BADSTATE,0,preq,NULL,"job already running");
 
     return(NULL);
     }
@@ -1071,7 +1143,7 @@ static job *chk_job_torun(
     {
     /* FAILURE - job must be in execution queue */
 
-    log_err(-1,"chk_job_torun","attempt to start job in non-execution queue");
+    log_err(-1,id,"attempt to start job in non-execution queue");
 
     req_reject(PBSE_IVALREQ,0,preq,NULL,"job not in execution queue");
 
@@ -1085,7 +1157,7 @@ static job *chk_job_torun(
     /* job has been checkpointed or files already staged in */
     /* in this case, exec_host must be already set	 	*/
 
-    if (prun->rq_destin[0] != '\0') 
+    if (prun->rq_destin != 0) 
       {
       /* specified destination must match exec_host */
 
@@ -1108,9 +1180,11 @@ static job *chk_job_torun(
       if ((rc = assign_hosts(  /* inside chk_job_torun() */
             pjob,
             pjob->ji_wattr[(int)JOB_ATR_exec_host].at_val.at_str,
-            0)) != 0) 
+            0,
+            FailHost,
+            EMsg)) != 0) 
         {
-        req_reject(PBSE_EXECTHERE,0,preq,NULL,"cannot assign hosts");
+        req_reject(PBSE_EXECTHERE,0,preq,FailHost,EMsg);
 
         return(NULL);
         }
@@ -1121,20 +1195,20 @@ static job *chk_job_torun(
     /* job has not run before or need not run there again */
     /* reserve nodes and set new exec_host */
 
-    if (prun->rq_destin[0] == '\0') 
+    if (prun->rq_destin == 0) 
       {
-      rc = assign_hosts(pjob,NULL,1);  /* inside chk_job_torun() */
+      rc = assign_hosts(pjob,NULL,1,FailHost,EMsg);  /* inside chk_job_torun() */
       } 
     else 
       {
-      rc = assign_hosts(pjob,prun->rq_destin,1);  /* inside chk_job_torun() */
+      rc = assign_hosts(pjob,prun->rq_destin,1,FailHost,EMsg);  /* inside chk_job_torun() */
       }
 
     if (rc != 0) 
       {
       /* FAILURE - cannot assign correct hosts */
 
-      req_reject(rc,0,preq,NULL,NULL);
+      req_reject(rc,0,preq,FailHost,EMsg);
 
       return(NULL);
       }
@@ -1186,7 +1260,9 @@ static int assign_hosts(
 
   job  *pjob,           /* I (modified) */
   char *given,          /* I (optional) list of requested hosts */
-  int   set_exec_host)  /* I (boolean) */
+  int   set_exec_host,  /* I (boolean) */
+  char *FailHost,       /* O (optional,minsize=1024) */
+  char *EMsg)           /* O (optional,minsize=1024) */
 
   {
   unsigned int	 dummy;
@@ -1196,7 +1272,13 @@ static int assign_hosts(
   resource	*pres;
   int		 rc = 0;
   extern char 	*mom_host;
-	
+
+  if (EMsg != NULL)
+    EMsg[0] = '\0';
+
+  if (FailHost != NULL)
+    FailHost[0] = '\0';
+
 #ifdef __TREQSCHED
   if ((given == NULL) || (given[0] == '\0'))
     {
@@ -1281,7 +1363,7 @@ static int assign_hosts(
     {
     if ((rc = is_ts_node(hosttoalloc)) != 0) 
       {
-      rc = set_nodes(pjob,hosttoalloc,&list);
+      rc = set_nodes(pjob,hosttoalloc,&list,FailHost,EMsg);
 
       set_exec_host = 1;	/* maybe new VPs, must set */
 
