@@ -115,44 +115,79 @@ extern void   set_old_nodes A_((job *));
  *	This request sends (via MOM) a signal to a running job.
  */
 
-void req_signaljob(preq)
-	struct batch_request *preq;
-{
-	job		 *pjob;
-	int		  rc;
+void req_signaljob(
 
-	if ((pjob = chk_job_request(preq->rq_ind.rq_signal.rq_jid, preq)) == 0)
-		return;
+  struct batch_request *preq)
 
-	/* the job must be running */
+  {
+  job *pjob;
+  int  rc;
 
-	if (pjob->ji_qs.ji_state != JOB_STATE_RUNNING) {
-		req_reject(PBSE_BADSTATE, 0, preq,NULL,NULL);
-		return;
-	}
+  if ((pjob = chk_job_request(preq->rq_ind.rq_signal.rq_jid, preq)) == 0)
+    {
+    return;
+    }
 
-	/* Special pseudo signals for suspend and resume require op/mgr */
+  /* the job must be running */
 
-	if ( (strcmp(preq->rq_ind.rq_signal.rq_signame, SIG_RESUME) == 0) ||
-	     (strcmp(preq->rq_ind.rq_signal.rq_signame, SIG_SUSPEND) == 0) ) {
+  if (pjob->ji_qs.ji_state != JOB_STATE_RUNNING) 
+    {
+    req_reject(PBSE_BADSTATE,0,preq,NULL,NULL);
 
-		if ((preq->rq_perm & (ATR_DFLAG_OPRD | ATR_DFLAG_OPWR |
-				      ATR_DFLAG_MGRD | ATR_DFLAG_MGWR)) == 0) {
-			/* for suspend/resume, must be mgr/op */
-			req_reject(PBSE_PERM, 0, preq,NULL,NULL);
-			return;
-		}
-		preq->rq_extra = pjob;	/* save job ptr for post_signal_req() */
-	}
-	
-	/* pass the request on to MOM */
+    return;
+    }
 
-	if ((rc = relay_to_mom(pjob->ji_qs.ji_un.ji_exect.ji_momaddr,
-			       preq, post_signal_req)))
-		req_reject(rc, 0, preq,NULL,NULL);	/* unable to get to MOM */
+  /* Special pseudo signals for suspend and resume require op/mgr */
 
-	/* After MOM acts and replies to us, we pick up in post_signal_req() */
-}
+  if (!strcmp(preq->rq_ind.rq_signal.rq_signame,SIG_RESUME) ||
+      !strcmp(preq->rq_ind.rq_signal.rq_signame,SIG_SUSPEND)) 
+    {
+    if ((preq->rq_perm & (ATR_DFLAG_OPRD|ATR_DFLAG_OPWR|ATR_DFLAG_MGRD|ATR_DFLAG_MGWR)) == 0) 
+      {
+      /* for suspend/resume, must be mgr/op */
+
+      req_reject(PBSE_PERM,0,preq,NULL,NULL);
+
+      return;
+      }
+
+    preq->rq_extra = pjob;  /* save job ptr for post_signal_req() */
+    }
+
+/* FIXME: need a race-free check for available free subnodes before
+ * resuming a suspended job */
+
+#ifdef DONOTSUSPINTJOB
+  /* interactive jobs don't resume correctly so don't allow a suspend */
+
+  if (!strcmp(preq->rq_ind.rq_signal.rq_signame,SIG_SUSPEND) &&
+      (pjob->ji_wattr[(int)JOB_ATR_interactive].at_flags & ATR_VFLAG_SET) &&
+      (pjob->ji_wattr[(int)JOB_ATR_interactive].at_val.at_long > 0))
+    {
+    req_reject(PBSE_JOBTYPE,0,preq,NULL,NULL);
+
+    return;
+    }
+#endif
+
+  /* pass the request on to MOM */
+
+  if ((rc = relay_to_mom(
+        pjob->ji_qs.ji_un.ji_exect.ji_momaddr,
+        preq, 
+        post_signal_req)))
+    {
+    req_reject(rc,0,preq,NULL,NULL);  /* unable to get to MOM */
+
+    return;
+    }
+
+  /* After MOM acts and replies to us, we pick up in post_signal_req() */
+
+  /* SUCCESS */
+
+  return;
+  }  /* END req_signaljob() */
 
 
 
@@ -223,27 +258,33 @@ static void post_signal_req(
 
     if (strcmp(preq->rq_ind.rq_signal.rq_signame,SIG_SUSPEND) == 0) 
       {
-      pjob->ji_qs.ji_svrflags |= JOB_SVFLG_Suspend;
+      if ((pjob->ji_qs.ji_svrflags & JOB_SVFLG_Suspend) == 0)
+        {
+        pjob->ji_qs.ji_svrflags |= JOB_SVFLG_Suspend;
 
-      set_statechar(pjob);
+        set_statechar(pjob);
 
-      job_save(pjob,SAVEJOB_QUICK);
+        job_save(pjob,SAVEJOB_QUICK);
 
-      /* release resources allocated to suspended job - NORWAY */
+        /* release resources allocated to suspended job - NORWAY */
 
-      free_nodes(pjob);
-      } 
+        free_nodes(pjob);
+        } 
+      }
     else if (strcmp(preq->rq_ind.rq_signal.rq_signame,SIG_RESUME) == 0) 
       {
-      /* re-allocate assigned node to resumed job - NORWAY */
+      if (pjob->ji_qs.ji_svrflags & JOB_SVFLG_Suspend)
+        {
+        /* re-allocate assigned node to resumed job - NORWAY */
 
-      set_old_nodes(pjob);
+        set_old_nodes(pjob);
 
-      pjob->ji_qs.ji_svrflags &= ~JOB_SVFLG_Suspend;
+        pjob->ji_qs.ji_svrflags &= ~JOB_SVFLG_Suspend;
 
-      set_statechar(pjob);
+        set_statechar(pjob);
 
-      job_save(pjob,SAVEJOB_QUICK);
+        job_save(pjob,SAVEJOB_QUICK);
+        }
       }
 			
     reply_ack(preq);
@@ -252,5 +293,5 @@ static void post_signal_req(
   return;
   }  /* END post_signal_req() */
 
-/* END req_signla.c */
+/* END req_signal.c */
 
