@@ -104,27 +104,30 @@
 #include "svrfunc.h"
 #include "net_connect.h"
 #include "pbs_nodes.h"
+#include "log.h"
 
 /* Global Data Items: */
 
 extern struct server   server;
-extern list_head       svr_alljobs;
-extern list_head       svr_queues;
+extern tlist_head       svr_alljobs;
+extern tlist_head       svr_queues;
 extern char            server_name[];
 extern attribute_def   svr_attr_def[];
 extern attribute_def   que_attr_def[];
 extern attribute_def   job_attr_def[];
-extern int	           pbs_mom_port;
-extern time_t	         time_now;
-extern char	          *msg_init_norerun;
+extern int	       pbs_mom_port;
+extern time_t	       time_now;
+extern char	      *msg_init_norerun;
 extern struct pbsnode *tfind_addr();
+extern int             LOGLEVEL;
 
 /* Extern Functions */
 
-int status_job A_((job *,struct batch_request *,svrattrl *,list_head *,int *));
-int status_attrib A_((svrattrl *,attribute_def *,attribute *,int,int,list_head *,int *,int));
+int status_job A_((job *,struct batch_request *,svrattrl *,tlist_head *,int *));
+int status_attrib A_((svrattrl *,attribute_def *,attribute *,int,int,tlist_head *,int *,int));
 extern int   svr_connect A_((pbs_net_t, unsigned int, void (*)(int), enum conn_type));
-extern int status_nodeattrib(svrattrl *,attribute_def *,struct pbsnode *,int,int,list_head *,int*);
+extern int status_nodeattrib(svrattrl *,attribute_def *,struct pbsnode *,int,int,tlist_head *,int*);
+extern int hasprop(struct pbsnode *, struct prop *);
 
 /* Private Data Definitions */
 
@@ -133,8 +136,8 @@ static int bad;
 /* The following private support functions are included */
 
 static void update_state_ct A_((attribute *, int *, char *));
-static int  status_que A_((pbs_queue *, struct batch_request *, list_head *));
-static int status_node A_(( struct pbsnode *, struct batch_request *, list_head *));
+static int  status_que A_((pbs_queue *, struct batch_request *, tlist_head *));
+static int status_node A_(( struct pbsnode *, struct batch_request *, tlist_head *));
 static void req_stat_job_step2 A_((struct stat_cntl *));
 static void stat_update A_((struct work_task *));
 
@@ -334,13 +337,13 @@ static void req_stat_job_step2(
     if (cntl->sc_conn >= 0)
       svr_disconnect(cntl->sc_conn); 	/* close connection to MOM */
 
-    if (rc) 
+    if (rc != 0) 
       {
       free(cntl);
 
       reply_free(preply);
 
-      req_reject(rc,0,preq,NULL,NULL);
+      req_reject(rc,0,preq,NULL,"cannot get update from mom");
 
       return;
       }
@@ -380,7 +383,7 @@ static void req_stat_job_step2(
 
     rc = status_job(pjob,preq,pal,&preply->brp_un.brp_status,&bad);
 
-    if (rc && (rc != PBSE_PERM)) 
+    if ((rc != 0) && (rc != PBSE_PERM)) 
       {
       req_reject(rc,bad,preq,NULL,NULL);
 
@@ -692,7 +695,7 @@ void req_stat_que(
 
     if (pque == NULL) 
       {
-      req_reject(PBSE_UNKQUE,0,preq,NULL,NULL);
+      req_reject(PBSE_UNKQUE,0,preq,NULL,"cannot located queue");
 
       return;
       }
@@ -735,7 +738,7 @@ void req_stat_que(
     {
     reply_free(preply);
 
-    req_reject(rc,bad,preq,NULL,NULL);
+    req_reject(rc,bad,preq,NULL,"status_queue failed");
     } 
   else 
     {
@@ -757,7 +760,7 @@ static int status_que(
 
   pbs_queue *pque,	/* ptr to que to status */
   struct batch_request *preq,
-  list_head *pstathd)	/* head of list to append status to */
+  tlist_head *pstathd)	/* head of list to append status to */
 
   {
   struct brp_status *pstat;
@@ -827,7 +830,7 @@ static int status_que(
  * req_stat_node - service the Status Node Request 
  *
  *	This request processes the request for status of a single node or
- *	set of nodes at a destinaion.
+ *	set of nodes at a destination.
  */
 
 void req_stat_node(
@@ -842,6 +845,10 @@ void req_stat_node(
   int	    rc   = 0;
   int	    type = 0;
   int	    i;
+  struct prop props;
+
+
+  char     *id = "req_stat_node";
 
   /*
    * first, check that the server indeed has a list of nodes
@@ -850,9 +857,18 @@ void req_stat_node(
    * meaning request is for all nodes in the server's jurisdiction
    */
 
-  if ((pbsndmast == 0) || (svr_totnodes <= 0)) 
+  if (LOGLEVEL >= 6)
     {
-    req_reject(PBSE_NONODES,0,preq,NULL,NULL);
+    log_record(
+      PBSEVENT_SCHED,
+      PBS_EVENTCLASS_REQUEST,
+      id,
+      "entered");
+    }
+
+  if ((pbsndmast == NULL) || (svr_totnodes <= 0)) 
+    {
+    req_reject(PBSE_NONODES,0,preq,NULL,"node list is empty");
 
     return;
     }
@@ -863,13 +879,27 @@ void req_stat_node(
     {
     type = 1;
     }
+  else if ((*name == ':') && (*(name+1) != '\0'))
+    {
+    if (!strcmp(name+1,"ALL"))
+      {
+      type = 1;  /* psuedo-group for all nodes */
+      }
+    else
+      {
+      type = 2;
+      props.name = name+1;
+      props.mark = 1;
+      props.next = NULL;
+      }
+    }
   else 
     {
     pnode = find_nodebyname(name);
 
     if (pnode == NULL) 
       {
-      req_reject(PBSE_UNKNODE,0,preq,NULL,NULL);
+      req_reject(PBSE_UNKNODE,0,preq,NULL,"cannot located specified node");
 
       return;
       }
@@ -881,15 +911,22 @@ void req_stat_node(
   CLEAR_HEAD(preply->brp_un.brp_status);
 
   if (type == 0) 
-    {		/*get status of the named node*/
+    {		
+    /* get status of the named node */
+
     rc = status_node(pnode,preq,&preply->brp_un.brp_status);
     } 
   else 
-    {			/*get status of all nodes     */
+    {			
+    /* get status of all or several nodes */
+
     for (i = 0;i < svr_totnodes;i++) 
       {
       pnode = pbsndmast[i];
 
+      if ((type == 2) && !hasprop(pnode,&props))
+        continue;
+        
       if ((rc = status_node(pnode,preq,&preply->brp_un.brp_status)) != 0)
         break;
       }
@@ -930,7 +967,7 @@ static int status_node(
 
   struct pbsnode       *pnode,    /* ptr to node receiving status query */
   struct batch_request *preq,
-  list_head            *pstathd)  /* head of list to append status to  */
+  tlist_head            *pstathd)  /* head of list to append status to  */
 
   {
   int		     rc = 0;
@@ -951,7 +988,7 @@ static int status_node(
 	
   pstat = (struct brp_status *)malloc(sizeof (struct brp_status));
 
-  if (pstat == (struct brp_status *)0)
+  if (pstat == NULL)
     {
     return(PBSE_SYSTEM);
     }
@@ -966,7 +1003,7 @@ static int status_node(
   /*add this new brp_status structure to the list hanging off*/
   /*the request's reply substructure                         */
 
-  append_link(pstathd, &pstat->brp_stlink, pstat);
+  append_link(pstathd,&pstat->brp_stlink,pstat);
 
   /*point to the list of node-attributes about which we want status*/
   /*hang that status information from the brp_attr field for this  */
