@@ -104,7 +104,9 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/socket.h>
+#include <stdio.h>
 #include "libpbs.h"
+#include "log.h"
 #include "server_limits.h"
 #include "net_connect.h"
 #include "svrfunc.h"
@@ -113,7 +115,6 @@
 
 /* global data */
 
-struct connect_handle connection[PBS_NET_MAX_CONNECTIONS]; /* used by API */
 
 extern int		 errno;
 
@@ -121,6 +122,7 @@ extern int		 pbs_errno;
 extern unsigned int	 pbs_server_port_dis;
 extern struct connection svr_conn[];
 extern pbs_net_t	 pbs_server_addr;
+extern int               LOGLEVEL;
 
 extern int addr_ok(pbs_net_t);
 extern void bad_node_warning(pbs_net_t);
@@ -136,9 +138,24 @@ int svr_connect(
   enum conn_type cntype)
 
   {
+  static char *id = "svr_connect";
+
   int handle;
   int sock;
 
+  if (LOGLEVEL >= 4)
+    {
+    sprintf(log_buffer,"attempting connect to %s port %d",
+      (hostaddr == pbs_server_addr) ? "server" : "host",
+      port);
+
+   log_event(
+      PBSEVENT_ADMIN,
+      PBS_EVENTCLASS_SERVER,
+      id,
+      log_buffer);
+    }
+
   /* First, determine if the request is to another server or ourselves */
 
   if ((hostaddr == pbs_server_addr) && (port == pbs_server_port_dis))
@@ -171,9 +188,15 @@ int svr_connect(
   if (func) 
     {
     if (cntype == ToServerASN)
+      {
       abort();	/* ASN kludge */	
+      }
     else
+      {
+      /* connect attempt to XXX? */
+
       add_conn(sock,ToServerDIS,hostaddr,port,func);
+      }
     }
 
   svr_conn[sock].cn_authen = PBS_NET_CONN_AUTHENTICATED;
